@@ -4,7 +4,7 @@
  * See the main source file 'vdr.c' for copyright information and
  * how to reach the author.
  *
- * $Id: channels.c 2.16 2010/06/05 13:33:57 kls Exp $
+ * $Id: channels.c 2.17 2010/11/07 12:24:59 kls Exp $
  */
 
 #include "channels.h"
@@ -13,9 +13,6 @@
 #include "epg.h"
 #include "libsi/si.h"
 #include "timers.h"
-#ifdef USE_ALTERNATECHANNEL
-#include "tools.h"
-#endif /* ALTERNATECHANNEL */
 
 // IMPORTANT NOTE: in the 'sscanf()' calls there is a blank after the '%d'
 // format characters in order to allow any number of blanks after a numeric
@@ -258,14 +255,6 @@ void cChannel::SetPortalName(const char *PortalName)
      }
 }
 
-#ifdef USE_ALTERNATECHANNEL
-void cChannel::SetAlternativeChannelID(const char *AlternativeChannelID)
-{
-  if (!isempty(AlternativeChannelID))
-    alternativeChannelID = tChannelID::FromString(AlternativeChannelID);
-}
-#endif /* ALTERNATECHANNEL */
-
 #define STRDIFF 0x01
 #define VALDIFF 0x02
 
@@ -273,12 +262,14 @@ static int IntArraysDiffer(const int *a, const int *b, const char na[][MAXLANGCO
 {
   int result = 0;
   for (int i = 0; a[i] || b[i]; i++) {
-      if (a[i] && na && nb && strcmp(na[i], nb[i]) != 0)
+      if (!a[i] || !b[i]) {
+         result |= VALDIFF;
+         break;
+         }
+      if (na && nb && strcmp(na[i], nb[i]) != 0)
          result |= STRDIFF;
       if (a[i] != b[i])
          result |= VALDIFF;
-      if (!a[i] || !b[i])
-         break;
       }
   return result;
 }
@@ -387,29 +378,6 @@ void cChannel::SetSubtitlingDescriptors(uchar *SubtitlingTypes, uint16_t *Compos
      }
 }
 
-#ifdef USE_TTXTSUBS
-void cChannel::SetTeletextSubtitlePages(tTeletextSubtitlePage pages[], int numberOfPages)
-{
-  int mod = CHANNELMOD_NONE;
-  if (totalTtxtSubtitlePages != (fixedTtxtSubtitlePages + numberOfPages))
-     mod |= CHANNELMOD_PIDS;
-  totalTtxtSubtitlePages = fixedTtxtSubtitlePages;
-  for (int i = 0; (i < numberOfPages) && (totalTtxtSubtitlePages < MAXTXTPAGES); i++) {
-      if (teletextSubtitlePages[totalTtxtSubtitlePages].ttxtMagazine != pages[i].ttxtMagazine ||
-          teletextSubtitlePages[totalTtxtSubtitlePages].ttxtPage != pages[i].ttxtPage ||
-          teletextSubtitlePages[totalTtxtSubtitlePages].ttxtType != pages[i].ttxtType ||
-          strcmp(teletextSubtitlePages[totalTtxtSubtitlePages].ttxtLanguage, pages[i].ttxtLanguage)) {
-         mod |= CHANNELMOD_PIDS;
-         teletextSubtitlePages[totalTtxtSubtitlePages] = pages[i];
-         }
-      totalTtxtSubtitlePages++;
-      }
-  modification |= mod;
-  Channels.SetModified();
-}
-
-#endif /* TTXTSUBS */
-
 void cChannel::SetCaIds(const int *CaIds)
 {
   if (caids[0] && caids[0] <= CA_USER_MAX)
@@ -538,28 +506,11 @@ cString cChannel::ToText(const cChannel *Channel)
         q += IntArrayToString(q, Channel->dpids, 10, Channel->dlangs, Channel->dtypes);
         }
      *q = 0;
-#ifdef USE_TTXTSUBS
-     const int TBufferSize = 5 + 1 + (MAXTXTPAGES * (3 + 1 + MAXLANGCODE1 + 1)) + 10; // '12345;150=deu,151=fin,...', +10: paranoia
-     char tpidbuf[TBufferSize];
-     q = tpidbuf;
-     q += snprintf(q, sizeof(tpidbuf), "%d", Channel->tpid);
-     if (Channel->fixedTtxtSubtitlePages > 0) {
-        q += snprintf(q, sizeof(tpidbuf) - (q - tpidbuf), ";");
-        for (int i = 0; i < Channel->fixedTtxtSubtitlePages; ++i) {
-            tTeletextSubtitlePage page = Channel->teletextSubtitlePages[i];
-            q += snprintf(q, sizeof(tpidbuf) - (q - tpidbuf), "%d=%s", page.PageNumber(), page.ttxtLanguage);
-            }
-        }
-#endif /* TTXTSUBS */
      char caidbuf[MAXCAIDS * 5 + 10]; // 5: 4 digits plus delimiting ',', 10: paranoia
      q = caidbuf;
      q += IntArrayToString(q, Channel->caids, 16);
      *q = 0;
-#ifdef USE_TTXTSUBS
-     buffer = cString::sprintf("%s:%d:%s:%s:%d:%s:%s:%s:%s:%d:%d:%d:%d\n", FullName, Channel->frequency, *Channel->parameters, *cSource::ToString(Channel->source), Channel->srate, vpidbuf, apidbuf, tpidbuf, caidbuf, Channel->sid, Channel->nid, Channel->tid, Channel->rid);
-#else
      buffer = cString::sprintf("%s:%d:%s:%s:%d:%s:%s:%d:%s:%d:%d:%d:%d\n", FullName, Channel->frequency, *Channel->parameters, *cSource::ToString(Channel->source), Channel->srate, vpidbuf, apidbuf, Channel->tpid, caidbuf, Channel->sid, Channel->nid, Channel->tid, Channel->rid);
-#endif /* TTXTSUBS */
      }
   return buffer;
 }
@@ -593,15 +544,8 @@ bool cChannel::Parse(const char *s)
      char *parambuf = NULL;
      char *vpidbuf = NULL;
      char *apidbuf = NULL;
-#ifdef USE_TTXTSUBS
-     char *tpidbuf = NULL;
-#endif /* TTXTSUBS */
      char *caidbuf = NULL;
-#ifdef USE_TTXTSUBS
-     int fields = sscanf(s, "%a[^:]:%d :%a[^:]:%a[^:] :%d :%a[^:]:%a[^:]:%a[^:]:%a[^:]:%d :%d :%d :%d ", &namebuf, &frequency, &parambuf, &sourcebuf, &srate, &vpidbuf, &apidbuf, &tpidbuf, &caidbuf, &sid, &nid, &tid, &rid);
-#else
      int fields = sscanf(s, "%a[^:]:%d :%a[^:]:%a[^:] :%d :%a[^:]:%a[^:]:%d :%a[^:]:%d :%d :%d :%d ", &namebuf, &frequency, &parambuf, &sourcebuf, &srate, &vpidbuf, &apidbuf, &tpid, &caidbuf, &sid, &nid, &tid, &rid);
-#endif /* TTXTSUBS */
      if (fields >= 9) {
         if (fields == 9) {
            // allow reading of old format
@@ -701,39 +645,6 @@ bool cChannel::Parse(const char *s)
               dtypes[NumDpids] = 0;
               }
 
-#ifdef USE_TTXTSUBS
-           if (tpidbuf) {
-              char *p;
-              fixedTtxtSubtitlePages = 0;
-              // 2001;150=deu,151=fin
-              if ((p = strchr(tpidbuf, ';')) != NULL) {
-                 char *q, *strtok_next;
-                 *p++ = 0;
-                 while ((q = strtok_r(p, ",", &strtok_next)) != NULL) {
-                       if (fixedTtxtSubtitlePages < MAXTXTPAGES) {
-                          int page;
-                          char *l = strchr(q, '=');
-                          if (l)
-                             *l++ = 0;
-                          if (sscanf(q, "%d", &page) == 1) {
-                             teletextSubtitlePages[fixedTtxtSubtitlePages] = tTeletextSubtitlePage(page);
-                             if (l)
-                                strn0cpy(teletextSubtitlePages[fixedTtxtSubtitlePages].ttxtLanguage, l, MAXLANGCODE1);
-                             fixedTtxtSubtitlePages++;
-                             }
-                          else
-                             esyslog("ERROR: invalid Teletext page!"); // no need to set ok to 'false'
-                          }
-                       else
-                          esyslog("ERROR: too many Teletext pages!"); // no need to set ok to 'false'
-                       p = NULL;
-                       }
-                 totalTtxtSubtitlePages = fixedTtxtSubtitlePages;
-                 }
-              if (sscanf(tpidbuf, "%d", &tpid) != 1)
-                 return false;
-              }
-#endif /* TTXTSUBS */
            if (caidbuf) {
               char *p = caidbuf;
               char *q;
@@ -770,9 +681,6 @@ bool cChannel::Parse(const char *s)
         free(sourcebuf);
         free(vpidbuf);
         free(apidbuf);
-#ifdef USE_TTXTSUBS
-        free(tpidbuf);
-#endif /* TTXTSUBS */
         free(caidbuf);
         free(namebuf);
         if (!GetChannelID().Valid()) {
@@ -846,50 +754,6 @@ bool cChannels::Load(const char *FileName, bool AllowComments, bool MustExist)
   return false;
 }
 
-#ifdef USE_ALTERNATECHANNEL
-bool cChannels::LoadAlternativeChannels(const char *FileName)
-{
-  FILE *fp;
-  char *line;
-  cReadLine ReadLine;
-  cChannel *origChannel;
-  tChannelID channelID;
-  if ((fp = fopen(FileName,"r"))==NULL)
-  {
-    esyslog("Can't open Alternative Channels-File <%s>",FileName);
-    return false;
-  }
-  while ((line = ReadLine.Read(fp)) != NULL)
-  {
-    if (line[0] != '#')
-    {
-      line=strtok(line, ";");
-      if (line != NULL)
-      {
-        channelID = tChannelID::FromString(line);
-        if (channelID == tChannelID::InvalidID)
-          dsyslog("Skipping invalid channel ID <%s>",line);
-        else {
-          origChannel = Channels.GetByChannelID(channelID);
-          if (!origChannel)
-            dsyslog("Skipping unknown channel ID <%s>",line);
-          else {
-            line=strtok(NULL, ";");
-            channelID = tChannelID::FromString(line);
-            if (channelID == tChannelID::InvalidID || !Channels.GetByChannelID(channelID))
-              dsyslog("Skipping invalid/unknown alternative channel ID <%s>",line);
-            else
-              origChannel->SetAlternativeChannelID(line);
-          }
-        }
-      }
-    }
-  } while (line != NULL);
-  fclose(fp);
-  return true;
-}
-#endif /* ALTERNATECHANNEL */
-
 void cChannels::HashChannel(cChannel *Channel)
 {
   channelsHashSid.Add(Channel, Channel->Sid());
