@@ -313,12 +313,6 @@ cSetup::cSetup(void)
   strcpy(OSDLanguage, ""); // default is taken from environment
   strcpy(OSDSkin, "sttng");
   strcpy(OSDTheme, "default");
-#ifdef USE_VALIDINPUT
-  ShowValidInput = 0;
-#endif /* VALIDINPUT */
-#ifdef USE_WAREAGLEICON
-  WarEagleIcons = 1;
-#endif /* WAREAGLEICON */
   PrimaryDVB = 1;
   ShowInfoOnChSwitch = 1;
   TimeoutRequChInfo = 1;
@@ -337,27 +331,13 @@ cSetup::cSetup(void)
   TimeTransponder = 0;
   MarginStart = 2;
   MarginStop = 10;
-#ifdef USE_JUMPINGSECONDS
-  JumpSeconds = 60;
-  JumpSecondsSlow = 10;
-  JumpSecondsRepeat = 300;
-#endif /* JUMPINGSECONDS */
   AudioLanguages[0] = -1;
   DisplaySubtitles = 0;
-#ifdef USE_TTXTSUBS
-  SupportTeletext = 0;
-#endif /* TTXTSUBS */
   SubtitleLanguages[0] = -1;
   SubtitleOffset = 0;
   SubtitleFgTransparency = 0;
   SubtitleBgTransparency = 0;
   EPGLanguages[0] = -1;
-#ifdef USE_DDEPGENTRY
-  DoubleEpgTimeDelta = 15;
-  DoubleEpgAction = 0;
-  MixEpgAction = 0;
-  DisableVPS = 0;
-#endif /* DDEPGENTRY */
   EPGScanTimeout = 5;
   EPGBugfixLevel = 3;
   EPGLinger = 0;
@@ -379,9 +359,6 @@ cSetup::cSetup(void)
   VideoDisplayFormat = 1;
   VideoFormat = 0;
   UpdateChannels = 5;
-#ifdef USE_CHANNELBIND
-  ChannelBindingByRid = 0;
-#endif /* CHANNELBIND */
   UseDolbyDigital = 1;
   ChannelInfoPos = 0;
   ChannelInfoTime = 5;
@@ -407,10 +384,6 @@ cSetup::cSetup(void)
   FontSmlSize = 18;
   FontFixSize = 20;
   MaxVideoFileSize = MAXVIDEOFILESIZEDEFAULT;
-#ifdef USE_HARDLINKCUTTER
-  MaxRecordingSize = DEFAULTRECORDINGSIZE;
-  HardLinkCutter = 0;
-#endif /* HARDLINKCUTTER */
   SplitEditedFiles = 0;
   DelTimeshiftRec = 0;
   MinEventTimeout = 30;
@@ -419,78 +392,18 @@ cSetup::cSetup(void)
   MultiSpeedMode = 0;
   ShowReplayMode = 0;
   ResumeID = 0;
-#ifdef USE_JUMPPLAY
-  JumpPlay = 0;
-  PlayJump = 0;
-  PauseLastMark = 0;
-  ReloadMarks = 0;
-#endif /* JUMPPLAY */
   CurrentChannel = -1;
   CurrentVolume = MAXVOLUME;
   CurrentDolby = 0;
-#ifdef USE_CHANNELPROVIDE
-  LocalChannelProvide = 1;
-#endif /* CHANNELPROVIDE */
   InitialChannel = 0;
   InitialVolume = -1;
-#ifdef USE_VOLCTRL
-  LRVolumeControl = 0;
-  LRChannelGroups = 1;
-  LRForwardRewind = 1;
-#endif /* VOLCTRL */
   ChannelsWrap = 0;
   EmergencyExit = 1;
-#ifdef USE_LIEMIEXT
-  ShowRecDate = 1;
-  ShowRecTime = 1;
-  ShowRecLength = 0;
-  ShowProgressBar = 0;
-  MenuCmdPosition = 0;
-#endif /* LIEMIEXT */
-#ifdef USE_LIRCSETTINGS
-  LircRepeatDelay = 350;
-  LircRepeatFreq = 100;
-  LircRepeatTimeout = 500;
-#endif /* LIRCSETTINGS */
-#ifdef USE_LNBSHARE
-  VerboseLNBlog = 0;
-  for (int i = 0; i < MAXDEVICES; i++) CardUsesLnbNr[i] = i + 1;
-#endif /* LNBSHARE */
-#ifdef USE_NOEPG
-  noEPGMode = 0;
-  noEPGList = NULL;
-#endif /* NOEPG */
-#ifdef USE_DVLVIDPREFER
-  UseVidPrefer = 0; // default = disabled
-  nVidPrefer = 1;
-  for (int zz = 1; zz < DVLVIDPREFER_MAX; zz++) {
-      VidPreferPrio[ zz ] = 50;
-      VidPreferSize[ zz ] = 100;
-      }
-  VidPreferSize[ 0 ] = 800;
-  VidPreferPrio[ 0 ] = 50;
-#endif /* DVLVIDPREFER */
 }
 
-#ifdef USE_NOEPG
-cSetup::~cSetup()
-{
-  if (noEPGList)
-     free(noEPGList);
-}
-#endif /* NOEPG */
-
 cSetup& cSetup::operator= (const cSetup &s)
 {
   memcpy(&__BeginData__, &s.__BeginData__, (char *)&s.__EndData__ - (char *)&s.__BeginData__);
-#ifdef USE_NOEPG
-  if (noEPGList) {
-     free(noEPGList);
-     noEPGList = NULL;
-     }
-  if (s.noEPGList)
-     noEPGList = strdup(s.noEPGList);
-#endif /* NOEPG */
   return *this;
 }
 
@@ -591,12 +504,6 @@ bool cSetup::Parse(const char *Name, const char *Value)
   if      (!strcasecmp(Name, "OSDLanguage"))       { strn0cpy(OSDLanguage, Value, sizeof(OSDLanguage)); I18nSetLocale(OSDLanguage); }
   else if (!strcasecmp(Name, "OSDSkin"))             Utf8Strn0Cpy(OSDSkin, Value, MaxSkinName);
   else if (!strcasecmp(Name, "OSDTheme"))            Utf8Strn0Cpy(OSDTheme, Value, MaxThemeName);
-#ifdef USE_VALIDINPUT
-  else if (!strcasecmp(Name, "ShowValidInput"))      ShowValidInput     = atoi(Value);
-#endif /* VALIDINPUT */
-#ifdef USE_WAREAGLEICON
-  else if (!strcasecmp(Name, "WarEagleIcons"))       WarEagleIcons      = atoi(Value);
-#endif /* WAREAGLEICON */
   else if (!strcasecmp(Name, "PrimaryDVB"))          PrimaryDVB         = atoi(Value);
   else if (!strcasecmp(Name, "ShowInfoOnChSwitch"))  ShowInfoOnChSwitch = atoi(Value);
   else if (!strcasecmp(Name, "TimeoutRequChInfo"))   TimeoutRequChInfo  = atoi(Value);
@@ -615,27 +522,13 @@ bool cSetup::Parse(const char *Name, const char *Value)
   else if (!strcasecmp(Name, "TimeTransponder"))     TimeTransponder    = atoi(Value);
   else if (!strcasecmp(Name, "MarginStart"))         MarginStart        = atoi(Value);
   else if (!strcasecmp(Name, "MarginStop"))          MarginStop         = atoi(Value);
-#ifdef USE_JUMPINGSECONDS
-  else if (!strcasecmp(Name, "JumpSeconds"))         JumpSeconds        = atoi(Value); 
-  else if (!strcasecmp(Name, "JumpSecondsSlow"))     JumpSecondsSlow    = atoi(Value);
-  else if (!strcasecmp(Name, "JumpSecondsRepeat"))   JumpSecondsRepeat  = atoi(Value);  
-#endif /* JUMPINGSECONDS */
   else if (!strcasecmp(Name, "AudioLanguages"))      return ParseLanguages(Value, AudioLanguages);
   else if (!strcasecmp(Name, "DisplaySubtitles"))    DisplaySubtitles   = atoi(Value);
-#ifdef USE_TTXTSUBS
-  else if (!strcasecmp(Name, "SupportTeletext"))     SupportTeletext    = atoi(Value);
-#endif /* TTXTSUBS */
   else if (!strcasecmp(Name, "SubtitleLanguages"))   return ParseLanguages(Value, SubtitleLanguages);
   else if (!strcasecmp(Name, "SubtitleOffset"))      SubtitleOffset     = atoi(Value);
   else if (!strcasecmp(Name, "SubtitleFgTransparency")) SubtitleFgTransparency = atoi(Value);
   else if (!strcasecmp(Name, "SubtitleBgTransparency")) SubtitleBgTransparency = atoi(Value);
   else if (!strcasecmp(Name, "EPGLanguages"))        return ParseLanguages(Value, EPGLanguages);
-#ifdef USE_DDEPGENTRY
-  else if (!strcasecmp(Name, "DoubleEpgTimeDelta"))  DoubleEpgTimeDelta = atoi(Value);
-  else if (!strcasecmp(Name, "DoubleEpgAction"))     DoubleEpgAction    = atoi(Value);
-  else if (!strcasecmp(Name, "MixEpgAction"))        MixEpgAction       = atoi(Value);
-  else if (!strcasecmp(Name, "DisableVPS"))          DisableVPS         = atoi(Value);
-#endif /* DDEPGENTRY */
   else if (!strcasecmp(Name, "EPGScanTimeout"))      EPGScanTimeout     = atoi(Value);
   else if (!strcasecmp(Name, "EPGBugfixLevel"))      EPGBugfixLevel     = atoi(Value);
   else if (!strcasecmp(Name, "EPGLinger"))           EPGLinger          = atoi(Value);
@@ -657,9 +550,6 @@ bool cSetup::Parse(const char *Name, const char *Value)
   else if (!strcasecmp(Name, "VideoDisplayFormat"))  VideoDisplayFormat = atoi(Value);
   else if (!strcasecmp(Name, "VideoFormat"))         VideoFormat        = atoi(Value);
   else if (!strcasecmp(Name, "UpdateChannels"))      UpdateChannels     = atoi(Value);
-#ifdef USE_CHANNELBIND
-  else if (!strcasecmp(Name, "ChannelBindingByRid")) ChannelBindingByRid= atoi(Value);
-#endif /* CHANNELBIND */
   else if (!strcasecmp(Name, "UseDolbyDigital"))     UseDolbyDigital    = atoi(Value);
   else if (!strcasecmp(Name, "ChannelInfoPos"))      ChannelInfoPos     = atoi(Value);
   else if (!strcasecmp(Name, "ChannelInfoTime"))     ChannelInfoTime    = atoi(Value);
@@ -685,10 +575,6 @@ bool cSetup::Parse(const char *Name, const char *Value)
   else if (!strcasecmp(Name, "FontSmlSize"))         FontSmlSize        = atoi(Value);
   else if (!strcasecmp(Name, "FontFixSize"))         FontFixSize        = atoi(Value);
   else if (!strcasecmp(Name, "MaxVideoFileSize"))    MaxVideoFileSize   = atoi(Value);
-#ifdef USE_HARDLINKCUTTER
-  else if (!strcasecmp(Name, "MaxRecordingSize"))    MaxRecordingSize   = atoi(Value);
-  else if (!strcasecmp(Name, "HardLinkCutter"))      HardLinkCutter     = atoi(Value);
-#endif /* HARDLINKCUTTER */
   else if (!strcasecmp(Name, "SplitEditedFiles"))    SplitEditedFiles   = atoi(Value);
   else if (!strcasecmp(Name, "DelTimeshiftRec"))     DelTimeshiftRec    = atoi(Value);
   else if (!strcasecmp(Name, "MinEventTimeout"))     MinEventTimeout    = atoi(Value);
@@ -697,92 +583,15 @@ bool cSetup::Parse(const char *Name, const char *Value)
   else if (!strcasecmp(Name, "MultiSpeedMode"))      MultiSpeedMode     = atoi(Value);
   else if (!strcasecmp(Name, "ShowReplayMode"))      ShowReplayMode     = atoi(Value);
   else if (!strcasecmp(Name, "ResumeID"))            ResumeID           = atoi(Value);
-#ifdef USE_JUMPPLAY
-  else if (!strcasecmp(Name, "JumpPlay"))            JumpPlay           = atoi(Value);
-  else if (!strcasecmp(Name, "PlayJump"))            PlayJump           = atoi(Value);
-  else if (!strcasecmp(Name, "PauseLastMark"))       PauseLastMark      = atoi(Value);
-  else if (!strcasecmp(Name, "ReloadMarks"))         ReloadMarks        = atoi(Value);
-#endif /* JUMPPLAY */
   else if (!strcasecmp(Name, "CurrentChannel"))      CurrentChannel     = atoi(Value);
   else if (!strcasecmp(Name, "CurrentVolume"))       CurrentVolume      = atoi(Value);
   else if (!strcasecmp(Name, "CurrentDolby"))        CurrentDolby       = atoi(Value);
-#ifdef USE_CHANNELPROVIDE
-  else if (!strcasecmp(Name, "LocalChannelProvide")) LocalChannelProvide = atoi(Value);
-#endif /* CHANNELPROVIDE */
   else if (!strcasecmp(Name, "InitialChannel"))      InitialChannel     = atoi(Value);
   else if (!strcasecmp(Name, "InitialVolume"))       InitialVolume      = atoi(Value);
-#ifdef USE_VOLCTRL
-  else if (!strcasecmp(Name, "LRVolumeControl"))     LRVolumeControl    = atoi(Value);
-  else if (!strcasecmp(Name, "LRChannelGroups"))     LRChannelGroups    = atoi(Value);
-  else if (!strcasecmp(Name, "LRForwardRewind"))     LRForwardRewind    = atoi(Value);
-#endif /* VOLCTRL */
   else if (!strcasecmp(Name, "ChannelsWrap"))        ChannelsWrap       = atoi(Value);
   else if (!strcasecmp(Name, "EmergencyExit"))       EmergencyExit      = atoi(Value);
-#ifdef USE_LIEMIEXT
-  else if (!strcasecmp(Name, "ShowRecDate"))         ShowRecDate        = atoi(Value);
-  else if (!strcasecmp(Name, "ShowRecTime"))         ShowRecTime        = atoi(Value);
-  else if (!strcasecmp(Name, "ShowRecLength"))       ShowRecLength      = atoi(Value);
-  else if (!strcasecmp(Name, "ShowProgressBar"))     ShowProgressBar    = atoi(Value);
-  else if (!strcasecmp(Name, "MenuCmdPosition"))     MenuCmdPosition    = atoi(Value);
-#endif /* LIEMIEXT */
-#ifdef USE_LIRCSETTINGS
-  else if (!strcasecmp(Name, "LircRepeatDelay"))     LircRepeatDelay    = atoi(Value);
-  else if (!strcasecmp(Name, "LircRepeatFreq"))      LircRepeatFreq     = atoi(Value);
-  else if (!strcasecmp(Name, "LircRepeatTimeout"))   LircRepeatTimeout  = atoi(Value);
-#endif /* LIRCSETTINGS */
-#ifdef USE_NOEPG
-  else if (!strcasecmp(Name, "noEPGMode"))           noEPGMode          = atoi(Value);
-  else if (!strcasecmp(Name, "noEPGList")) {
-     free(noEPGList);
-     noEPGList = Value ? strdup(Value) : NULL;
-     }
-#endif /* NOEPG */
-#ifdef USE_DVLVIDPREFER
-  else if (strcasecmp(Name, "UseVidPrefer") == 0)    UseVidPrefer       = atoi(Value);
-  else if (strcasecmp(Name, "nVidPrefer") == 0)      nVidPrefer         = atoi(Value);
-  else if (strstr(Name, "VidPrefer") == Name) {
-     char *x = (char *)&Name[ strlen(Name) - 1 ];
-     int vN;
-
-     if (isdigit(*x) != 0) {
-        while (isdigit(*x) != 0)
-              x--;
-        x++;
-        }
-
-     vN = atoi(x);
-     if (vN < DVLVIDPREFER_MAX) {
-        if (strstr(Name, "VidPreferPrio") == Name) {
-           VidPreferPrio[ vN ] = atoi(Value);
-           if (VidPreferPrio[ vN ] > 99)
-              VidPreferPrio[ vN ] = 99;
-           }
-        else if (strstr(Name, "VidPreferSize") == Name) {
-           VidPreferSize[ vN ] = atoi(Value);
-           }
-        else
-           return false;
-        }
-     }
-#endif /* DVLVIDPREFER */
   else
-#ifdef USE_LNBSHARE
-  if (!strcasecmp(Name, "VerboseLNBlog")) VerboseLNBlog = atoi(Value);
-  else {
-    char tmp[20];
-    bool result = false;
-    for (int i = 1; i <= MAXDEVICES; i++) {
-      sprintf(tmp, "Card%dusesLNBnr", i);
-      if (!strcasecmp(Name, tmp)) {
-        CardUsesLnbNr[i - 1] = atoi(Value);
-        result = true;
-      }
-    }  
-     return result;
-  }
-#else
      return false;
-#endif /* LNBSHARE */
   return true;
 }
 
@@ -791,12 +600,6 @@ bool cSetup::Save(void)
   Store("OSDLanguage",        OSDLanguage);
   Store("OSDSkin",            OSDSkin);
   Store("OSDTheme",           OSDTheme);
-#ifdef USE_VALIDINPUT
-  Store("ShowValidInput",     ShowValidInput);
-#endif /* VALIDINPUT */
-#ifdef USE_WAREAGLEICON
-  Store("WarEagleIcons",      WarEagleIcons);
-#endif /* WAREAGLEICON */
   Store("PrimaryDVB",         PrimaryDVB);
   Store("ShowInfoOnChSwitch", ShowInfoOnChSwitch);
   Store("TimeoutRequChInfo",  TimeoutRequChInfo);
@@ -815,27 +618,13 @@ bool cSetup::Save(void)
   Store("TimeTransponder",    TimeTransponder);
   Store("MarginStart",        MarginStart);
   Store("MarginStop",         MarginStop);
-#ifdef USE_JUMPINGSECONDS
-  Store("JumpSeconds",        JumpSeconds);
-  Store("JumpSecondsSlow",    JumpSecondsSlow);
-  Store("JumpSecondsRepeat",  JumpSecondsRepeat);
-#endif /* JUMPINGSECONDS */
   StoreLanguages("AudioLanguages", AudioLanguages);
   Store("DisplaySubtitles",   DisplaySubtitles);
-#ifdef USE_TTXTSUBS
-  Store("SupportTeletext",    SupportTeletext);
-#endif /* TTXTSUBS */
   StoreLanguages("SubtitleLanguages", SubtitleLanguages);
   Store("SubtitleOffset",     SubtitleOffset);
   Store("SubtitleFgTransparency", SubtitleFgTransparency);
   Store("SubtitleBgTransparency", SubtitleBgTransparency);
   StoreLanguages("EPGLanguages", EPGLanguages);
-#ifdef USE_DDEPGENTRY
-  Store("DoubleEpgTimeDelta", DoubleEpgTimeDelta);
-  Store("DoubleEpgAction",    DoubleEpgAction);
-  Store("MixEpgAction",       MixEpgAction);
-  Store("DisableVPS",         DisableVPS);
-#endif /* DDEPGENTRY */
   Store("EPGScanTimeout",     EPGScanTimeout);
   Store("EPGBugfixLevel",     EPGBugfixLevel);
   Store("EPGLinger",          EPGLinger);
@@ -857,9 +646,6 @@ bool cSetup::Save(void)
   Store("VideoDisplayFormat", VideoDisplayFormat);
   Store("VideoFormat",        VideoFormat);
   Store("UpdateChannels",     UpdateChannels);
-#ifdef USE_CHANNELBIND
-  Store("ChannelBindingByRid",ChannelBindingByRid);
-#endif /* CHANNELBIND */
   Store("UseDolbyDigital",    UseDolbyDigital);
   Store("ChannelInfoPos",     ChannelInfoPos);
   Store("ChannelInfoTime",    ChannelInfoTime);
@@ -893,69 +679,13 @@ bool cSetup::Save(void)
   Store("MultiSpeedMode",     MultiSpeedMode);
   Store("ShowReplayMode",     ShowReplayMode);
   Store("ResumeID",           ResumeID);
-#ifdef USE_JUMPPLAY
-  Store("JumpPlay",           JumpPlay);
-  Store("PlayJump",           PlayJump);
-  Store("PauseLastMark",      PauseLastMark);
-  Store("ReloadMarks",        ReloadMarks);
-#endif /* JUMPPLAY */
   Store("CurrentChannel",     CurrentChannel);
   Store("CurrentVolume",      CurrentVolume);
   Store("CurrentDolby",       CurrentDolby);
-#ifdef USE_CHANNELPROVIDE
-  Store("LocalChannelProvide",LocalChannelProvide);
-#endif /* CHANNELPROVIDE */
-#ifdef USE_HARDLINKCUTTER
-  Store("MaxRecordingSize",   MaxRecordingSize);
-  Store("HardLinkCutter",     HardLinkCutter);
-#endif /* HARDLINKCUTTER */
   Store("InitialChannel",     InitialChannel);
   Store("InitialVolume",      InitialVolume);
-#ifdef USE_VOLCTRL
-  Store("LRVolumeControl",    LRVolumeControl);
-  Store("LRChannelGroups",    LRChannelGroups);
-  Store("LRForwardRewind",    LRForwardRewind);
-#endif /* VOLCTRL */
   Store("ChannelsWrap",       ChannelsWrap);
   Store("EmergencyExit",      EmergencyExit);
-#ifdef USE_LIEMIEXT
-  Store("ShowRecDate",        ShowRecDate);
-  Store("ShowRecTime",        ShowRecTime);
-  Store("ShowRecLength",      ShowRecLength);
-  Store("ShowProgressBar",    ShowProgressBar);
-  Store("MenuCmdPosition",    MenuCmdPosition);
-#endif /* LIEMIEXT */
-#ifdef USE_LIRCSETTINGS
-  Store("LircRepeatDelay",    LircRepeatDelay);
-  Store("LircRepeatFreq",     LircRepeatFreq);
-  Store("LircRepeatTimeout",  LircRepeatTimeout);
-#endif /* LIRCSETTINGS */
-#ifdef USE_LNBSHARE
-  Store("VerboseLNBlog",       VerboseLNBlog);
-  char tmp[20];
-  if (cDevice::NumDevices() > 1) {
-     for (int i = 1; i <= cDevice::NumDevices(); i++) {
-        sprintf(tmp, "Card%dusesLNBnr", i);
-        Store(tmp, CardUsesLnbNr[i - 1]);
-     }
-  }
-#endif /* LNBSHARE */
-#ifdef USE_NOEPG
-  Store("noEPGMode",          noEPGMode);
-  Store("noEPGList",          noEPGList ? noEPGList : "");
-#endif /* NOEPG */
-#ifdef USE_DVLVIDPREFER
-  Store ("UseVidPrefer",      UseVidPrefer);
-  Store ("nVidPrefer",        nVidPrefer);
-
-  char vidBuf[32];
-  for (int zz = 0; zz < nVidPrefer; zz++) {
-      sprintf(vidBuf, "VidPreferPrio%d", zz);
-      Store (vidBuf, VidPreferPrio[zz]);
-      sprintf(vidBuf, "VidPreferSize%d", zz);
-      Store (vidBuf, VidPreferSize[zz]);
-      }
-#endif /* DVLVIDPREFER */
 
   Sort();
 
