@@ -4,7 +4,7 @@
  * See the main source file 'vdr.c' for copyright information and
  * how to reach the author.
  *
- * $Id: config.h 2.28 2010/09/12 11:31:21 kls Exp $
+ * $Id: config.h 2.30 2011/03/13 12:02:31 kls Exp $
  */
 
 #ifndef __CONFIG_H
@@ -22,17 +22,13 @@
 
 // VDR's own version number:
 
-#define VDRVERSION  "1.7.16"
-#define VDRVERSNUM   10716  // Version * 10000 + Major * 100 + Minor
+#define VDRVERSION  "1.7.18"
+#define VDRVERSNUM   10718  // Version * 10000 + Major * 100 + Minor
 
 // The plugin API's version number:
 
-#define APIVERSION  "1.7.16"
-#define APIVERSNUM   10716  // Version * 10000 + Major * 100 + Minor
-
-#ifdef USE_YAEPG
-#define YAEPGHDVERSNUM 1
-#endif /* YAEPG */
+#define APIVERSION  "1.7.18"
+#define APIVERSNUM   10718  // Version * 10000 + Major * 100 + Minor
 
 // When loading plugins, VDR searches them by their APIVERSION, which
 // may be smaller than VDRVERSION in case there have been no changes to
@@ -40,29 +36,9 @@
 // plugins to work with newer versions of the core VDR as long as no
 // VDR header files have changed.
 
-#ifdef USE_CHANNELBIND
-#define CHANNELBINDINGVERSNUM 2
-#endif /* CHANNELBIND */
-
-#ifdef USE_JUMPPLAY
-#define JUMPPLAYVERSNUM 100
-#endif /* JUMPPLAY */
-
-#ifdef USE_LIEMIEXT
-#define LIEMIKUUTIO  130
-#endif /* LIEMIEXT */
-
-#ifdef USE_MAINMENUHOOKS
-#define MAINMENUHOOKSVERSNUM 1.0
-#endif /* MAINMENUHOOKS */
-
 #define MAXPRIORITY 99
 #define MAXLIFETIME 99
 
-#ifdef USE_DVLVIDPREFER
-#define DVLVIDPREFER_MAX 12
-#endif /* DVLVIDPREFER */
-
 #define MINOSDWIDTH   480
 #define MAXOSDWIDTH  1920
 #define MINOSDHEIGHT  324
@@ -240,12 +216,6 @@ public:
   char OSDLanguage[I18N_MAX_LOCALE_LEN];
   char OSDSkin[MaxSkinName];
   char OSDTheme[MaxThemeName];
-#ifdef USE_VALIDINPUT
-  int ShowValidInput;
-#endif /* VALIDINPUT */
-#ifdef USE_WAREAGLEICON
-  int WarEagleIcons;
-#endif /* WAREAGLEICON */
   int PrimaryDVB;
   int ShowInfoOnChSwitch;
   int TimeoutRequChInfo;
@@ -263,24 +233,12 @@ public:
   int TimeSource;
   int TimeTransponder;
   int MarginStart, MarginStop;
-#ifdef USE_JUMPINGSECONDS
-  int JumpSeconds, JumpSecondsSlow, JumpSecondsRepeat;
-#endif /* JUMPINGSECONDS */
   int AudioLanguages[I18N_MAX_LANGUAGES + 1];
   int DisplaySubtitles;
-#ifdef USE_TTXTSUBS
-  int SupportTeletext;
-#endif /* TTXTSUBS */
   int SubtitleLanguages[I18N_MAX_LANGUAGES + 1];
   int SubtitleOffset;
   int SubtitleFgTransparency, SubtitleBgTransparency;
   int EPGLanguages[I18N_MAX_LANGUAGES + 1];
-#ifdef USE_DDEPGENTRY
-  int DoubleEpgTimeDelta;
-  int DoubleEpgAction;
-  int MixEpgAction;
-  int DisableVPS;
-#endif /* DDEPPGENTRY */
   int EPGScanTimeout;
   int EPGBugfixLevel;
   int EPGLinger;
@@ -300,9 +258,6 @@ public:
   int VideoDisplayFormat;
   int VideoFormat;
   int UpdateChannels;
-#ifdef USE_CHANNELBIND
-  int ChannelBindingByRid;
-#endif /* CHANNELBIND */
   int UseDolbyDigital;
   int ChannelInfoPos;
   int ChannelInfoTime;
@@ -322,10 +277,6 @@ public:
   int FontSmlSize;
   int FontFixSize;
   int MaxVideoFileSize;
-#ifdef USE_HARDLINKCUTTER
-  int MaxRecordingSize;
-  int HardLinkCutter;
-#endif /* HARDLINKCUTTER */
   int SplitEditedFiles;
   int DelTimeshiftRec;
   int MinEventTimeout, MinUserInactivity;
@@ -333,60 +284,15 @@ public:
   int MultiSpeedMode;
   int ShowReplayMode;
   int ResumeID;
-#ifdef USE_JUMPPLAY
-  int JumpPlay;
-  int PlayJump;
-  int PauseLastMark;
-  int ReloadMarks;
-#endif /* JUMPPLAY */
   int CurrentChannel;
   int CurrentVolume;
   int CurrentDolby;
-#ifdef USE_CHANNELPROVIDE
-  int LocalChannelProvide;
-#endif /* CHANNELPROVIDE */
   int InitialChannel;
   int InitialVolume;
-#ifdef USE_VOLCTRL
-  int LRVolumeControl;
-  int LRChannelGroups;
-  int LRForwardRewind;
-#endif /* VOLCTRL */
   int ChannelsWrap;
   int EmergencyExit;
-#ifdef USE_LIRCSETTINGS
-  int LircRepeatDelay;
-  int LircRepeatFreq;
-  int LircRepeatTimeout;
-#endif /* LIRCSETTINGS */
-#ifdef USE_LIEMIEXT
-  int ShowRecDate, ShowRecTime, ShowRecLength, ShowProgressBar, MenuCmdPosition;
-#endif /* LIEMIEXT */
-#ifdef USE_LNBSHARE
-  int VerboseLNBlog;
-  #define MAXDEVICES 16 // Since VDR 1.3.32 we can not #include "device.h" for MAXDEVICES anymore.
-                        // With this workaround a warning will be shown during compilation if
-                        // MAXDEVICES changes in device.h.
-  int CardUsesLnbNr[MAXDEVICES];
-#endif /* LNBSHARE */
-#ifdef USE_NOEPG
-  int noEPGMode;
-#endif /* NOEPG */
-#ifdef USE_DVLVIDPREFER
-  int UseVidPrefer;  // 0 = VDR's default, 1 = use
-  int nVidPrefer;
-  int VidPreferPrio[DVLVIDPREFER_MAX];
-  int VidPreferSize[DVLVIDPREFER_MAX];
-#endif /* DVLVIDPREFER */
-
   int __EndData__;
-#ifdef USE_NOEPG
-  char *noEPGList; // pointer not to be flat-copied
-#endif /* NOEPG */
   cSetup(void);
-#ifdef USE_NOEPG
-  ~cSetup();
-#endif /* NOEPG */
   cSetup& operator= (const cSetup &s);
   bool Load(const char *FileName);
   bool Save(void);
