@@ -4,7 +4,7 @@
  * See the main source file 'vdr.c' for copyright information and
  * how to reach the author.
  *
- * $Id: device.c 2.37 2010/06/03 13:35:02 kls Exp $
+ * $Id: device.c 2.38 2011/02/25 15:12:03 kls Exp $
  */
 
 #include "device.h"
@@ -18,9 +18,6 @@
 #include "receiver.h"
 #include "status.h"
 #include "transfer.h"
-#ifdef USE_TTXTSUBS
-#include "vdrttxtsubshooks.h"
-#endif /* TTXTSUBS */
 
 // --- cLiveSubtitle ---------------------------------------------------------
 
@@ -147,15 +144,6 @@ void cDevice::SetUseDevice(int n)
      useDevice |= (1 << n);
 }
 
-#ifdef USE_LNBSHARE
-void cDevice::SetLnbNr(void)
-{
-  for (int i = 0; i < numDevices; i++) {
-    device[i]->SetLnbNrFromSetup();
-  }
-}
-#endif /* LNBSHARE */
-
 int cDevice::NextCardIndex(int n)
 {
   if (n > 0) {
@@ -248,9 +236,6 @@ cDevice *cDevice::GetDevice(const cChannel *Channel, int Priority, bool LiveView
   int NumCamSlots = CamSlots.Count();
   int SlotPriority[NumCamSlots];
   int NumUsableSlots = 0;
-#ifdef USE_MCLI
-  bool InternalCamNeeded = false;
-#endif /* MCLI */
   if (Channel->Ca() >= CA_ENCRYPTED_MIN) {
      for (cCamSlot *CamSlot = CamSlots.First(); CamSlot; CamSlot = CamSlots.Next(CamSlot)) {
          SlotPriority[CamSlot->Index()] = MAXPRIORITY + 1; // assumes it can't be used
@@ -264,11 +249,7 @@ cDevice *cDevice::GetDevice(const cChannel *Channel, int Priority, bool LiveView
             }
          }
      if (!NumUsableSlots)
-#ifdef USE_MCLI
-        InternalCamNeeded = true; // no CAM is able to decrypt this channel
-#else
         return NULL; // no CAM is able to decrypt this channel
-#endif /* MCLI */
      }
 
   bool NeedsDetachReceivers = false;
@@ -284,21 +265,11 @@ cDevice *cDevice::GetDevice(const cChannel *Channel, int Priority, bool LiveView
              continue; // this device shall be temporarily avoided
           if (Channel->Ca() && Channel->Ca() <= CA_DVB_MAX && Channel->Ca() != device[i]->CardIndex() + 1)
              continue; // a specific card was requested, but not this one
-#ifdef USE_MCLI
-          if (InternalCamNeeded && !device[i]->HasInternalCam())
-             continue; // no CAM is able to decrypt this channel and the device uses vdr handled CAMs
-          if (NumUsableSlots && !device[i]->HasInternalCam() && !CamSlots.Get(j)->Assign(device[i], true))
-#else
           if (NumUsableSlots && !CamSlots.Get(j)->Assign(device[i], true))
-#endif /* MCLI */
              continue; // CAM slot can't be used with this device
           bool ndr;
           if (device[i]->ProvidesChannel(Channel, Priority, &ndr)) { // this device is basicly able to do the job
-#ifdef USE_MCLI
-             if (NumUsableSlots && !device[i]->HasInternalCam() && device[i]->CamSlot() && device[i]->CamSlot() != CamSlots.Get(j))
-#else
              if (NumUsableSlots && device[i]->CamSlot() && device[i]->CamSlot() != CamSlots.Get(j))
-#endif /* MCLI */
                 ndr = true; // using a different CAM slot requires detaching receivers
              // Put together an integer number that reflects the "impact" using
              // this device would have on the overall system. Each condition is represented
@@ -312,48 +283,19 @@ cDevice *cDevice::GetDevice(const cChannel *Channel, int Priority, bool LiveView
              imp <<= 1; imp |= device[i]->Receiving();                                                               // avoid devices that are receiving
              imp <<= 4; imp |= GetClippedNumProvidedSystems(4, device[i]) - 1;                                       // avoid cards which support multiple delivery systems
              imp <<= 1; imp |= device[i] == cTransferControl::ReceiverDevice();                                      // avoid the Transfer Mode receiver device
-#ifdef USE_LNBSHARE
-             int badPriority = device[i]->GetMaxBadPriority(Channel);
-             if (badPriority < 0 )                  // a device receiving with lower priority would need to be stopped
-             {
-                imp <<= 8; imp |= min(max(device[i]->Priority() + MAXPRIORITY, 0), 0xFF);                       // use the device with the lowest priority (+MAXPRIORITY to assure that values -99..99 can be used)
-             } else {
-                imp <<= 8; imp |= min(max(max(device[i]->Priority(), badPriority) + MAXPRIORITY, 0), 0xFF);          // use the device with the lowest priority (+MAXPRIORITY to assure that values -99..99 can be used)
-             }
-#else
              imp <<= 8; imp |= min(max(device[i]->Priority() + MAXPRIORITY, 0), 0xFF);                               // use the device with the lowest priority (+MAXPRIORITY to assure that values -99..99 can be used)
-#endif /* LNBSHARE */
-#ifdef USE_MCLI
-             imp <<= 8; imp |= min(max(((NumUsableSlots && !device[i]->HasInternalCam()) ? SlotPriority[j] : 0) + MAXPRIORITY, 0), 0xFF);              // use the CAM slot with the lowest priority (+MAXPRIORITY to assure that values -99..99 can be used)
-#else
              imp <<= 8; imp |= min(max((NumUsableSlots ? SlotPriority[j] : 0) + MAXPRIORITY, 0), 0xFF);              // use the CAM slot with the lowest priority (+MAXPRIORITY to assure that values -99..99 can be used)
-#endif /* MCLI */
              imp <<= 1; imp |= ndr;                                                                                  // avoid devices if we need to detach existing receivers
              imp <<= 1; imp |= device[i]->IsPrimaryDevice();                                                         // avoid the primary device
-#ifdef USE_LNBSHARE
-             imp |= (badPriority == -1);                                                                               // avoid cards where the actual device needs to be switched
-#endif /* LNBSHARE */
-#ifdef USE_MCLI
-             imp <<= 1; imp |= (NumUsableSlots || InternalCamNeeded) ? 0 : device[i]->HasCi();                       // avoid cards with Common Interface for FTA channels
-#else
              imp <<= 1; imp |= NumUsableSlots ? 0 : device[i]->HasCi();                                              // avoid cards with Common Interface for FTA channels
-#endif /* MCLI */
              imp <<= 1; imp |= device[i]->HasDecoder();                                                              // avoid full featured cards
-#ifdef USE_MCLI
-             imp <<= 1; imp |= (NumUsableSlots && !device[i]->HasInternalCam()) ? !ChannelCamRelations.CamDecrypt(Channel->GetChannelID(), j + 1) : 0; // prefer CAMs that are known to decrypt this channel
-#else
              imp <<= 1; imp |= NumUsableSlots ? !ChannelCamRelations.CamDecrypt(Channel->GetChannelID(), j + 1) : 0; // prefer CAMs that are known to decrypt this channel
-#endif /* MCLI */
              if (imp < Impact) {
                 // This device has less impact than any previous one, so we take it.
                 Impact = imp;
                 d = device[i];
                 NeedsDetachReceivers = ndr;
-#ifdef USE_MCLI
-                if (NumUsableSlots && !device[i]->HasInternalCam())
-#else
                 if (NumUsableSlots)
-#endif /* MCLI */
                    s = CamSlots.Get(j);
                 }
              }
@@ -619,13 +561,6 @@ int cDevice::OpenFilter(u_short Pid, u_char Tid, u_char Mask)
   return -1;
 }
 
-#ifdef USE_MCLI
-int cDevice::ReadFilter(int Handle, void *Buffer, size_t Length)
-{
-  return safe_read(Handle, Buffer, Length);
-}
-#endif /* MCLI */
-
 void cDevice::CloseFilter(int Handle)
 {
   close(Handle);
@@ -667,11 +602,7 @@ bool cDevice::ProvidesTransponder(const cChannel *Channel) const
 bool cDevice::ProvidesTransponderExclusively(const cChannel *Channel) const
 {
   for (int i = 0; i < numDevices; i++) {
-#ifdef USE_LNBSHARE
-      if (device[i] && device[i] != this && device[i]->ProvidesTransponder(Channel) && device[i]->IsShareLnb(this)  )
-#else
       if (device[i] && device[i] != this && device[i]->ProvidesTransponder(Channel))
-#endif /* LNBSHARE */
          return false;
       }
   return true;
@@ -704,24 +635,6 @@ bool cDevice::MaySwitchTransponder(void)
 
 bool cDevice::SwitchChannel(const cChannel *Channel, bool LiveView)
 {
-
-#ifdef USE_LNBSHARE
-  cDevice *tmpDevice;
-       if (this->GetMaxBadPriority(Channel) >= 0) {
-               Skins.Message(mtInfo, tr("Channel locked by LNB!"));
-               return false;
-       }
-       while ((tmpDevice = GetBadDevice(Channel)) != NULL) {
-               if (tmpDevice->IsPrimaryDevice() && LiveView)
-                       tmpDevice->SwitchChannelForced(Channel, true);
-               else
-                       tmpDevice->SwitchChannelForced(Channel, false);
-       }
-    return SwitchChannelForced(Channel, LiveView);
-}
-bool cDevice::SwitchChannelForced(const cChannel *Channel, bool LiveView)
-{
-#endif /* LNBSHARE */
   if (LiveView) {
      isyslog("switching to channel %d", Channel->Number());
      cControl::Shutdown(); // prevents old channel from being shown too long if GetDevice() takes longer
@@ -752,9 +665,6 @@ bool cDevice::SwitchChannel(int Direction)
      cChannel *channel;
      while ((channel = Channels.GetByNumber(n, Direction)) != NULL) {
            // try only channels which are currently available
-#ifdef USE_PINPLUGIN
-        if (cStatus::MsgChannelProtected(0, channel) == false)
-#endif /* PINPLUGIN */
            if (GetDevice(channel, 0, true))
               break;
            n = channel->Number() + Direction;
@@ -774,53 +684,8 @@ bool cDevice::SwitchChannel(int Direction)
   return result;
 }
 
-#ifdef USE_LNBSHARE
-cDevice *cDevice::GetBadDevice(const cChannel *Channel)
-{
-  if(!cSource::IsSat(Channel->Source())) return NULL;  // no conflict if the new channel is not on sat
-  if(!ProvidesSource(cSource::stSat)) return NULL;     // no conflict if this device is not on sat
-  for (int i = 0; i < numDevices; i++) {
-    if (this != device[i] && device[i]->IsShareLnb(this) &&  device[i]->IsLnbConflict(Channel) ) {
-    	// there is a conflict between device[i] and 'this' if we tune this to Channel
-      if (Setup.VerboseLNBlog) {
-        isyslog("LNB %d: Device check for channel %d on device %d. LNB or DiSEq conflict with device %d", LnbNr(), Channel->Number(), this->DeviceNumber(), i);
-      }
-      return device[i];
-    }
-  }
-  if (Setup.VerboseLNBlog) { 
-    isyslog("LNB %d: Device check for for channel %d on device %d. OK", LnbNr(), Channel->Number(), this->DeviceNumber());
-  }
-  return NULL;
-}
-
-int cDevice::GetMaxBadPriority(const cChannel *Channel) const
-{                                
-  if(!cSource::IsSat(Channel->Source())) return -2;  // no conflict if the new channel is not on sat
-  if(!ProvidesSource(cSource::stSat)) return -2;     // no conflict if this device is not on sat
-
-  int maxBadPriority = -2;
-  for (int i = 0; i < numDevices; i++) {
-    if (this != device[i] && device[i]->IsShareLnb(this) && device[i]->IsLnbConflict(Channel) ) {
-    	// there is a conflict between device[i] and 'this' if we tune this to Channel
-      if (device[i]->Receiving() && device[i]->Priority() > maxBadPriority) maxBadPriority = device[i]->Priority();
-      if (i == ActualDevice()->CardIndex() && maxBadPriority < -1 ) maxBadPriority = -1;
-    }
-  }
-
-  if (Setup.VerboseLNBlog) { 
-    isyslog("LNB %d: Request for channel %d on device %d. MaxBadPriority is %d", LnbNr(), Channel->Number(), this->DeviceNumber(), maxBadPriority);
-  }
-  return maxBadPriority;
-}
-#endif /* LNBSHARE */
 eSetChannelResult cDevice::SetChannel(const cChannel *Channel, bool LiveView)
 {
-#ifdef USE_PINPLUGIN
-  if (LiveView && cStatus::MsgChannelProtected(this, Channel) == true)
-     return scrNotAvailable;
-#endif /* PINPLUGIN */
-
   if (LiveView) {
      StopReplay();
      DELETENULL(liveSubtitle);
@@ -832,12 +697,6 @@ eSetChannelResult cDevice::SetChannel(const cChannel *Channel, bool LiveView)
   bool NeedsTransferMode = Device != this;
 
   eSetChannelResult Result = scrOk;
-  
-#ifdef USE_LNBSHARE
-  if (Setup.VerboseLNBlog) {
-    isyslog("LNB %d: Switching device %d to channel %d", LnbNr(), this->DeviceNumber(), Channel->Number());
-  }
-#endif /* LNBSHARE */
 
   // If this DVB card can't receive this channel, let's see if we can
   // use the card that actually can receive it and transfer data from there:
@@ -1153,10 +1012,6 @@ void cDevice::EnsureSubtitleTrack(void)
      int LanguagePreference = INT_MAX; // higher than the maximum possible value
      for (int i = ttSubtitleFirst; i <= ttSubtitleLast; i++) {
          const tTrackId *TrackId = GetTrack(eTrackType(i));
-#ifdef USE_LIEMIEXT
-         if (TrackId && TrackId->id && (I18nIsPreferredLanguage(Setup.SubtitleLanguages, TrackId->language, LanguagePreference) ||
-             ((i == ttSubtitleFirst + 8) && !(*TrackId->language) && (LanguagePreference == INT_MAX))))
-#endif /* LIEMIEXT */
          if (TrackId && TrackId->id && I18nIsPreferredLanguage(Setup.SubtitleLanguages, TrackId->language, LanguagePreference))
             PreferredTrack = eTrackType(i);
          }
@@ -1232,11 +1087,17 @@ void cDevice::StillPicture(const uchar *Data, int Length)
                  int l;
                  while (const uchar *p = TsToPes.GetPes(l)) {
                        int Offset = Size;
-                       Size += l;
-                       buf = (uchar *)realloc(buf, Size);
-                       if (!buf)
+                       int NewSize = Size + l;
+                       if (uchar *NewBuffer = (uchar *)realloc(buf, NewSize)) {
+                          Size = NewSize;
+                          buf = NewBuffer;
+                          memcpy(buf + Offset, p, l);
+                          }
+                       else {
+                          LOG_ERROR_STR("out of memory");
+                          free(buf);
                           return;
-                       memcpy(buf + Offset, p, l);
+                          }
                        }
                  TsToPes.Reset();
                  }
@@ -1248,11 +1109,17 @@ void cDevice::StillPicture(const uchar *Data, int Length)
      int l;
      while (const uchar *p = TsToPes.GetPes(l)) {
            int Offset = Size;
-           Size += l;
-           buf = (uchar *)realloc(buf, Size);
-           if (!buf)
+           int NewSize = Size + l;
+           if (uchar *NewBuffer = (uchar *)realloc(buf, NewSize)) {
+              Size = NewSize;
+              buf = NewBuffer;
+              memcpy(buf + Offset, p, l);
+              }
+           else {
+              esyslog("ERROR: out of memory");
+              free(buf);
               return;
-           memcpy(buf + Offset, p, l);
+              }
            }
      StillPicture(buf, Size);
      free(buf);
@@ -1368,15 +1235,6 @@ int cDevice::PlayPesPacket(const uchar *Data, int Length, bool VideoOnly)
                   }
                break;
           case 0xBD: { // private stream 1
-#ifdef USE_TTXTSUBS
-               // EBU Teletext data, ETSI EN 300 472
-               // if PES data header length = 24 and data_identifier = 0x10..0x1F (EBU Data)
-               if (Data[8] == 0x24 && Data[45] >= 0x10 && Data[45] < 0x20) {
-                  cVDRTtxtsubsHookListener::Hook()->PlayerTeletextData((uint8_t*)Data, Length);
-                  break;
-                  }
-#endif /* TTXTSUBS */
-
                int PayloadOffset = Data[8] + 9;
 
                // Compatibility mode for old subtitles plugin:
@@ -1536,9 +1394,6 @@ int cDevice::PlayTs(const uchar *Data, int Length, bool VideoOnly)
      tsToPesVideo.Reset();
      tsToPesAudio.Reset();
      tsToPesSubtitle.Reset();
-#ifdef USE_TTXTSUBS
-     tsToPesTeletext.Reset();
-#endif /* TTXTSUBS */
      }
   else if (Length < TS_SIZE) {
      esyslog("ERROR: skipped %d bytes of TS fragment", Length);
@@ -1584,19 +1439,6 @@ int cDevice::PlayTs(const uchar *Data, int Length, bool VideoOnly)
                     if (!VideoOnly || HasIBPTrickSpeed())
                        PlayTsSubtitle(Data, TS_SIZE);
                     }
-#ifdef USE_TTXTSUBS
-                 else if (Pid == patPmtParser.Tpid()) {
-                    if (!VideoOnly || HasIBPTrickSpeed()) {
-                       int l;
-                       tsToPesTeletext.PutTs(Data, Length);
-                       if (const uchar *p = tsToPesTeletext.GetPes(l)) {
-                          if ((l > 45) && (p[0] == 0x00) && (p[1] == 0x00) && (p[2] == 0x01) && (p[3] == 0xbd) && (p[8] == 0x24) && (p[45] >= 0x10) && (p[45] < 0x20))
-                             cVDRTtxtsubsHookListener::Hook()->PlayerTeletextData((uchar *)p, l, false, patPmtParser.TeletextSubtitlePages(), patPmtParser.TotalTeletextSubtitlePages());
-                          tsToPesTeletext.Reset();
-                          }
-                       }
-                    }
-#endif /* TTXTSUBS */
                  }
               }
            else if (Pid == patPmtParser.Ppid()) {
