@@ -7,10 +7,13 @@
  * Original author: Marco Schller <marco@lordzodiac.de>
  * With some input from the "subtitle plugin" by Pekka Virtanen <pekka.virtanen@sci.fi>
  *
- * $Id: dvbsubtitle.c 2.7 2010/08/29 14:08:23 kls Exp $
+ * $Id: dvbsubtitle.c 2.17 2011/04/17 14:34:05 kls Exp $
  */
 
+
 #include "dvbsubtitle.h"
+#define __STDC_FORMAT_MACROS // Required for format specifiers
+#include <inttypes.h>
 #include "device.h"
 
 #define PAGE_COMPOSITION_SEGMENT   0x10
@@ -420,7 +423,7 @@ public:
   int PageId(void) { return pageId; }
   int Version(void) { return version; }
   int State(void) { return state; }
-  tArea *GetAreas(void);
+  tArea *GetAreas(double FactorX, double FactorY);
   cSubtitleClut *GetClutById(int ClutId, bool New = false);
   cSubtitleObject *GetObjectById(int ObjectId);
   cSubtitleRegion *GetRegionById(int RegionId, bool New = false);
@@ -446,16 +449,16 @@ cDvbSubtitlePage::~cDvbSubtitlePage()
 {
 }
 
-tArea *cDvbSubtitlePage::GetAreas(void)
+tArea *cDvbSubtitlePage::GetAreas(double FactorX, double FactorY)
 {
   if (regions.Count() > 0) {
      tArea *Areas = new tArea[regions.Count()];
      tArea *a = Areas;
      for (cSubtitleRegion *sr = regions.First(); sr; sr = regions.Next(sr)) {
-         a->x1 = sr->HorizontalAddress();
-         a->y1 = sr->VerticalAddress();
-         a->x2 = sr->HorizontalAddress() + sr->Width() - 1;
-         a->y2 = sr->VerticalAddress() + sr->Height() - 1;
+         a->x1 = int(round(FactorX * sr->HorizontalAddress()));
+         a->y1 = int(round(FactorY * sr->VerticalAddress()));
+         a->x2 = int(round(FactorX * (sr->HorizontalAddress() + sr->Width() - 1)));
+         a->y2 = int(round(FactorY * (sr->VerticalAddress() + sr->Height() - 1)));
          a->bpp = sr->Bpp();
          while ((a->Width() & 3) != 0)
                a->x2++; // aligns width to a multiple of 4, so 2, 4 and 8 bpp will work
@@ -570,12 +573,17 @@ void cDvbSubtitleAssembler::Reset(void)
 bool cDvbSubtitleAssembler::Realloc(int Size)
 {
   if (Size > size) {
-     size = max(Size, 2048);
-     data = (uchar *)realloc(data, size);
-     if (!data) {
+     Size = max(Size, 2048);
+     if (uchar *NewBuffer = (uchar *)realloc(data, Size)) {
+        size = Size;
+        data = NewBuffer;
+        }
+     else {
         esyslog("ERROR: can't allocate memory for subtitle assembler");
         length = 0;
         size = 0;
+        free(data);
+        data = NULL;
         return false;
         }
      }
@@ -611,9 +619,11 @@ private:
   int timeout;
   tArea *areas;
   int numAreas;
+  double osdFactorX;
+  double osdFactorY;
   cVector<cBitmap *> bitmaps;
 public:
-  cDvbSubtitleBitmaps(int64_t Pts, int Timeout, tArea *Areas, int NumAreas);
+  cDvbSubtitleBitmaps(int64_t Pts, int Timeout, tArea *Areas, int NumAreas, double OsdFactorX, double OsdFactorY);
   ~cDvbSubtitleBitmaps();
   int64_t Pts(void) { return pts; }
   int Timeout(void) { return timeout; }
@@ -621,12 +631,14 @@ public:
   void Draw(cOsd *Osd);
   };
 
-cDvbSubtitleBitmaps::cDvbSubtitleBitmaps(int64_t Pts, int Timeout, tArea *Areas, int NumAreas)
+cDvbSubtitleBitmaps::cDvbSubtitleBitmaps(int64_t Pts, int Timeout, tArea *Areas, int NumAreas, double OsdFactorX, double OsdFactorY)
 {
   pts = Pts;
   timeout = Timeout;
   areas = Areas;
   numAreas = NumAreas;
+  osdFactorX = OsdFactorX;
+  osdFactorY = OsdFactorY;
 }
 
 cDvbSubtitleBitmaps::~cDvbSubtitleBitmaps()
@@ -643,9 +655,30 @@ void cDvbSubtitleBitmaps::AddBitmap(cBitmap *Bitmap)
 
 void cDvbSubtitleBitmaps::Draw(cOsd *Osd)
 {
+  bool Scale = !(DoubleEqual(osdFactorX, 1.0) && DoubleEqual(osdFactorY, 1.0));
+  bool AntiAlias = true;
+  if (Scale && osdFactorX > 1.0 || osdFactorY > 1.0) {
+     // Upscaling requires 8bpp:
+     int Bpp[MAXOSDAREAS];
+     for (int i = 0; i < numAreas; i++) {
+         Bpp[i] = areas[i].bpp;
+         areas[i].bpp = 8;
+         }
+     if (Osd->CanHandleAreas(areas, numAreas) != oeOk) {
+        for (int i = 0; i < numAreas; i++)
+            Bpp[i] = areas[i].bpp = Bpp[i];
+        AntiAlias = false;
+        }
+     }
   if (Osd->SetAreas(areas, numAreas) == oeOk) {
-     for (int i = 0; i < bitmaps.Size(); i++)
-         Osd->DrawBitmap(bitmaps[i]->X0(), bitmaps[i]->Y0(), *bitmaps[i]);
+     for (int i = 0; i < bitmaps.Size(); i++) {
+         cBitmap *b = bitmaps[i];
+         if (Scale)
+            b = b->Scaled(osdFactorX, osdFactorY, AntiAlias);
+         Osd->DrawBitmap(int(round(b->X0() * osdFactorX)), int(round(b->Y0() * osdFactorY)), *b);
+         if (b != bitmaps[i])
+            delete b;
+         }
      Osd->Flush();
      }
 }
@@ -661,10 +694,11 @@ cDvbSubtitleConverter::cDvbSubtitleConverter(void)
   osd = NULL;
   frozen = false;
   ddsVersionNumber = -1;
-  displayWidth = 720;
-  displayHeight = 576;
-  displayHorizontalOffset = 0;
-  displayVerticalOffset = 0;
+  displayWidth = windowWidth = 720;
+  displayHeight = windowHeight = 576;
+  windowHorizontalOffset = 0;
+  windowVerticalOffset = 0;
+  SetOsdData();
   pages = new cList<cDvbSubtitlePage>;
   bitmaps = new cList<cDvbSubtitleBitmaps>;
   Start();
@@ -694,10 +728,11 @@ void cDvbSubtitleConverter::Reset(void)
   DELETENULL(osd);
   frozen = false;
   ddsVersionNumber = -1;
-  displayWidth = 720;
-  displayHeight = 576;
-  displayHorizontalOffset = 0;
-  displayVerticalOffset = 0;
+  displayWidth = windowWidth = 720;
+  displayHeight = windowHeight = 576;
+  windowHorizontalOffset = 0;
+  windowVerticalOffset = 0;
+  SetOsdData();
   Unlock();
 }
 
@@ -718,7 +753,7 @@ int cDvbSubtitleConverter::ConvertFragments(const uchar *Data, int Length)
      if (Length > PayloadOffset + SubstreamHeaderLength) {
         int64_t pts = PesHasPts(Data) ? PesGetPts(Data) : 0;
         if (pts)
-           dbgconverter("Converter PTS: %lld\n", pts);
+           dbgconverter("Converter PTS: %"PRId64"\n", pts);
         const uchar *data = Data + PayloadOffset + SubstreamHeaderLength; // skip substream header
         int length = Length - PayloadOffset - SubstreamHeaderLength; // skip substream header
         if (ResetSubtitleAssembler)
@@ -754,7 +789,7 @@ int cDvbSubtitleConverter::Convert(const uchar *Data, int Length)
      if (Length > PayloadOffset) {
         int64_t pts = PesGetPts(Data);
         if (pts)
-           dbgconverter("Converter PTS: %lld\n", pts);
+           dbgconverter("Converter PTS: %"PRId64"\n", pts);
         const uchar *data = Data + PayloadOffset;
         int length = Length - PayloadOffset;
         if (length > 3) {
@@ -781,7 +816,7 @@ int cDvbSubtitleConverter::Convert(const uchar *Data, int Length)
   return 0;
 }
 
-#define LimitTo32Bit(n) (n & 0x00000000FFFFFFFFL)
+#define LimitTo32Bit(n) ((n) & 0x00000000FFFFFFFFL)
 #define MAXDELTA 40000 // max. reasonable PTS/STC delta in ms
 
 void cDvbSubtitleConverter::Action(void)
@@ -801,17 +836,11 @@ void cDvbSubtitleConverter::Action(void)
            Lock();
            if (cDvbSubtitleBitmaps *sb = bitmaps->First()) {
               int64_t STC = cDevice::PrimaryDevice()->GetSTC();
-              int64_t Delta = 0;
-              if (STC >= 0) {
-                 Delta = LimitTo32Bit(sb->Pts()) - LimitTo32Bit(STC); // some devices only deliver 32 bits
-                 if (Delta > (int64_t(1) << 31))
-                    Delta -= (int64_t(1) << 32);
-                 else if (Delta < -((int64_t(1) << 31) - 1))
-                    Delta += (int64_t(1) << 32);
-                 }
-              else {
-                 //TODO sync on PTS? are there actually devices that don't deliver an STC?
-                 }
+              int64_t Delta = LimitTo32Bit(sb->Pts()) - LimitTo32Bit(STC); // some devices only deliver 32 bits
+              if (Delta > (int64_t(1) << 31))
+                 Delta -= (int64_t(1) << 32);
+              else if (Delta < -((int64_t(1) << 31) - 1))
+                 Delta += (int64_t(1) << 32);
               Delta /= 90; // STC and PTS are in 1/90000s
               if (Delta <= MAXDELTA) {
                  if (Delta <= 0) {
@@ -819,7 +848,7 @@ void cDvbSubtitleConverter::Action(void)
                     if (AssertOsd()) {
                        sb->Draw(osd);
                        Timeout.Set(sb->Timeout() * 1000);
-                       dbgconverter("PTS: %lld  STC: %lld (%lld) timeout: %d\n", sb->Pts(), cDevice::PrimaryDevice()->GetSTC(), Delta, sb->Timeout());
+                       dbgconverter("PTS: %"PRId64"  STC: %"PRId64" (%"PRId64") timeout: %d\n", sb->Pts(), cDevice::PrimaryDevice()->GetSTC(), Delta, sb->Timeout());
                        }
                     bitmaps->Del(sb);
                     }
@@ -851,9 +880,29 @@ tColor cDvbSubtitleConverter::yuv2rgb(int Y, int Cb, int Cr)
   return (Er << 16) | (Eg << 8) | Eb;
 }
 
+void cDvbSubtitleConverter::SetOsdData(void)
+{
+  int OsdWidth, OsdHeight;
+  double OsdAspect;
+  int VideoWidth, VideoHeight;
+  double VideoAspect;
+  cDevice::PrimaryDevice()->GetOsdSize(OsdWidth, OsdHeight, OsdAspect);
+  cDevice::PrimaryDevice()->GetVideoSize(VideoWidth, VideoHeight, VideoAspect);
+  if (OsdWidth == displayWidth && OsdHeight == displayHeight) {
+     osdFactorX = osdFactorY = 1.0;
+     osdDeltaX = osdDeltaY = 0;
+     }
+  else {
+     osdFactorX = VideoAspect * OsdHeight / displayWidth;
+     osdFactorY = double(OsdHeight) / displayHeight;
+     osdDeltaX = (OsdWidth - displayWidth * osdFactorX) / 2;
+     osdDeltaY = (OsdHeight - displayHeight * osdFactorY) / 2;
+     }
+}
+
 bool cDvbSubtitleConverter::AssertOsd(void)
 {
-  return osd || (osd = cOsdProvider::NewOsd(displayHorizontalOffset, displayVerticalOffset + Setup.SubtitleOffset, OSD_LEVEL_SUBTITLES));
+  return osd || (osd = cOsdProvider::NewOsd(int(round(osdFactorX * windowHorizontalOffset + osdDeltaX)), int(round(osdFactorY * windowVerticalOffset + osdDeltaY)) + Setup.SubtitleOffset, OSD_LEVEL_SUBTITLES));
 }
 
 int cDvbSubtitleConverter::ExtractSegment(const uchar *Data, int Length, int64_t Pts)
@@ -889,7 +938,7 @@ int cDvbSubtitleConverter::ExtractSegment(const uchar *Data, int Length, int64_t
             page->SetTimeout(Data[6]);
             page->SetState((Data[6 + 1] & 0x0C) >> 2);
             page->regions.Clear();
-            dbgpages("Update page id %d version %d pts %lld timeout %d state %d\n", pageId, page->Version(), page->Pts(), page->Timeout(), page->State());
+            dbgpages("Update page id %d version %d pts %"PRId64" timeout %d state %d\n", pageId, page->Version(), page->Pts(), page->Timeout(), page->State());
             for (int i = 6 + 2; i < segmentLength; i += 6) {
                 cSubtitleRegion *region = page->GetRegionById(Data[i], true);
                 region->SetHorizontalAddress((Data[i + 2] << 8) + Data[i + 3]);
@@ -1017,16 +1066,17 @@ int cDvbSubtitleConverter::ExtractSegment(const uchar *Data, int Length, int64_t
             int version = (Data[6] & 0xF0) >> 4;
             if (version != ddsVersionNumber) {
                int displayWindowFlag   = (Data[6] & 0x08) >> 3;
-               displayHorizontalOffset = 0;
-               displayVerticalOffset   = 0;
-               displayWidth            = ((Data[7] << 8) | Data[8]) + 1;
-               displayHeight           = ((Data[9] << 8) | Data[10]) + 1;
+               windowHorizontalOffset = 0;
+               windowVerticalOffset   = 0;
+               displayWidth = windowWidth   = ((Data[7] << 8) | Data[8]) + 1;
+               displayHeight = windowHeight = ((Data[9] << 8) | Data[10]) + 1;
                if (displayWindowFlag) { 
-                  displayHorizontalOffset = (Data[11] << 8) | Data[12];                                 // displayWindowHorizontalPositionMinimum
-                  displayWidth            = ((Data[13] << 8) | Data[14]) - displayHorizontalOffset + 1; // displayWindowHorizontalPositionMaximum
-                  displayVerticalOffset   = (Data[15] << 8) | Data[16];                                 // displayWindowVerticalPositionMinimum
-                  displayHeight           = ((Data[17] << 8) | Data[18]) - displayVerticalOffset + 1;   // displayWindowVerticalPositionMaximum
+                  windowHorizontalOffset = (Data[11] << 8) | Data[12];                                // displayWindowHorizontalPositionMinimum
+                  windowWidth            = ((Data[13] << 8) | Data[14]) - windowHorizontalOffset + 1; // displayWindowHorizontalPositionMaximum
+                  windowVerticalOffset   = (Data[15] << 8) | Data[16];                                // displayWindowVerticalPositionMinimum
+                  windowHeight           = ((Data[17] << 8) | Data[18]) - windowVerticalOffset + 1;   // displayWindowVerticalPositionMaximum
                   }
+               SetOsdData();
                SetupChanged();
                ddsVersionNumber = version;
                }
@@ -1049,7 +1099,7 @@ void cDvbSubtitleConverter::FinishPage(cDvbSubtitlePage *Page)
 {
   if (!AssertOsd())
      return;
-  tArea *Areas = Page->GetAreas();
+  tArea *Areas = Page->GetAreas(osdFactorX, osdFactorY);
   int NumAreas = Page->regions.Count();
   int Bpp = 8;
   bool Reduced = false;
@@ -1086,7 +1136,7 @@ void cDvbSubtitleConverter::FinishPage(cDvbSubtitlePage *Page)
             }
          }
      }
-  cDvbSubtitleBitmaps *Bitmaps = new cDvbSubtitleBitmaps(Page->Pts(), Page->Timeout(), Areas, NumAreas);
+  cDvbSubtitleBitmaps *Bitmaps = new cDvbSubtitleBitmaps(Page->Pts(), Page->Timeout(), Areas, NumAreas, osdFactorX, osdFactorY);
   bitmaps->Add(Bitmaps);
   for (cSubtitleRegion *sr = Page->regions.First(); sr; sr = Page->regions.Next(sr)) {
       int posX = sr->HorizontalAddress();
