@@ -24,27 +24,8 @@
 class cEIT : public SI::EIT {
 public:
   cEIT(cSchedules *Schedules, int Source, u_char Tid, const u_char *Data, bool OnlyRunningStatus = false);
-#ifdef USE_NOEPG
-private:
-  bool allowedEPG(tChannelID kanalID);
-#endif /* NOEPG */
   };
 
-#ifdef USE_NOEPG
-bool cEIT::allowedEPG(tChannelID kanalID) {
-  bool found = false;
-  bool rc = false;
-
-  if (::Setup.noEPGList && strstr(::Setup.noEPGList, kanalID.ToString()))
-     found = true;
-
-  if ((Setup.noEPGMode == 1 && found) || (Setup.noEPGMode == 0 && !found))
-     rc = true;
-
-  return rc;
-}
-#endif /* NOEPG */
-
 cEIT::cEIT(cSchedules *Schedules, int Source, u_char Tid, const u_char *Data, bool OnlyRunningStatus)
 :SI::EIT(Data, false)
 {
@@ -56,14 +37,6 @@ cEIT::cEIT(cSchedules *Schedules, int Source, u_char Tid, const u_char *Data, bo
   if (!channel)
      return; // only collect data for known channels
 
-#ifdef USE_NOEPG
-  // only use epg from channels not blocked by noEPG-patch
-  tChannelID kanalID;
-  kanalID = channel->GetChannelID();
-  if (!allowedEPG(kanalID))
-     return;
-#endif /* NOEPG */
-
   cSchedule *pSchedule = (cSchedule *)Schedules->GetSchedule(channel, true);
 
   bool Empty = true;
@@ -110,87 +83,7 @@ cEIT::cEIT(cSchedules *Schedules, int Source, u_char Tid, const u_char *Data, bo
          uchar TableID = pEvent->TableID();
          if (TableID == 0x00) {
             if (pEvent->Version() == getVersionNumber())
-#ifdef USE_DDEPGENTRY
-            {
-               if(Setup.MixEpgAction == 0)
-                   continue;
-
-               //printf("in");
-               //printf("%s", pEvent->GetTimeString());
-               // to use the info of the original epg, update the extern one,
-               // if it has less info
-               SI::Descriptor *d;
-               SI::ExtendedEventDescriptors *ExtendedEventDescriptors = NULL;
-               //SI::ExtendedEventDescriptor *eed = NULL;
-               SI::ShortEventDescriptor *ShortEventDescriptor = NULL;
-               //SI::ShortEventDescriptor *sed = NULL;
-               //SI::TimeShiftedEventDescriptor *tsed = NULL;
-               //cLinkChannels *LinkChannels = NULL;
-               for (SI::Loop::Iterator it2; (d = SiEitEvent.eventDescriptors.getNext(it2));)
-               {
-                  if(d->getDescriptorTag() == SI::ShortEventDescriptorTag)
-                  {
-                     int LanguagePreferenceShort = -1;
-                     SI::ShortEventDescriptor *sed = (SI::ShortEventDescriptor *)d;
-                     if (I18nIsPreferredLanguage(Setup.EPGLanguages, sed->languageCode, LanguagePreferenceShort) || !ShortEventDescriptor)
-                     {
-                        delete ShortEventDescriptor;
-                        ShortEventDescriptor = sed;
-                        d = NULL; // so that it is not deleted
-                     }
-                  }
-                  else if(d->getDescriptorTag() == SI::ExtendedEventDescriptorTag)
-                  {
-                     int LanguagePreferenceExt = -1;
-                     bool UseExtendedEventDescriptor = false;
-                     SI::ExtendedEventDescriptor *eed = (SI::ExtendedEventDescriptor *)d;
-                     if (I18nIsPreferredLanguage(Setup.EPGLanguages, eed->languageCode, LanguagePreferenceExt) || !ExtendedEventDescriptors)
-                     {
-                        delete ExtendedEventDescriptors;
-                        ExtendedEventDescriptors = new SI::ExtendedEventDescriptors;
-                        UseExtendedEventDescriptor = true;
-                     }
-                     if (UseExtendedEventDescriptor)
-                     {
-                        ExtendedEventDescriptors->Add(eed);
-                        d = NULL; // so that it is not deleted
-                     }
-                     if (eed->getDescriptorNumber() == eed->getLastDescriptorNumber())
-                        UseExtendedEventDescriptor = false;
-                  }
-                  delete d;
-               }
-               if(pEvent)
-               {
-
-                  if(ShortEventDescriptor)
-                  {
-                     char buffer[256];
-                     if(ShortEventDescriptor->text.getText(buffer, sizeof(buffer)) && pEvent->ShortText() && (strlen(ShortEventDescriptor->text.getText(buffer, sizeof(buffer))) > strlen(pEvent->ShortText())))
-                     {
-                        pEvent->SetShortText(ShortEventDescriptor->text.getText(buffer, sizeof(buffer)));
-                        pEvent->FixEpgBugs();
-                     }
-                  }
-                  if(ExtendedEventDescriptors)
-                  {
-                     char buffer[ExtendedEventDescriptors->getMaximumTextLength(": ") + 1];
-                     //pEvent->SetDescription(ExtendedEventDescriptors->getText(buffer, sizeof(buffer), ": "));
-
-                     if(ExtendedEventDescriptors->getText(buffer, sizeof(buffer), ": ") && pEvent->Description() && (strlen(ExtendedEventDescriptors->getText(buffer, sizeof(buffer), ": ")) > strlen(pEvent->Description())))
-                     {
-                        pEvent->SetDescription(ExtendedEventDescriptors->getText(buffer, sizeof(buffer), ": "));
-                        pEvent->FixEpgBugs();
-                     }
-                  }
-               }
-               delete ExtendedEventDescriptors;
-               delete ShortEventDescriptor;
                continue;
-            }
-#else
-               continue;
-#endif /* DDEPGENTRY */
             HasExternalData = ExternalData = true;
             }
          // If the new event has a higher table ID, let's skip it.
@@ -215,11 +108,7 @@ cEIT::cEIT(cSchedules *Schedules, int Source, u_char Tid, const u_char *Data, bo
       if (newEvent)
          pSchedule->AddEvent(newEvent);
       if (Tid == 0x4E) { // we trust only the present/following info on the actual TS
-#ifdef USE_DDEPGENTRY
-         if (Setup.DisableVPS == 0 && SiEitEvent.getRunningStatus() >= SI::RunningStatusNotRunning)
-#else
          if (SiEitEvent.getRunningStatus() >= SI::RunningStatusNotRunning)
-#endif /* DDEPGENTRY */
             pSchedule->SetRunningStatus(pEvent, SiEitEvent.getRunningStatus(), channel);
          }
       if (OnlyRunningStatus)
@@ -408,82 +297,6 @@ cEIT::cEIT(cSchedules *Schedules, int Source, u_char Tid, const u_char *Data, bo
       if (LinkChannels)
          channel->SetLinkChannels(LinkChannels);
       Modified = true;
-
-#ifdef USE_DDEPGENTRY
-      //to avoid double epg-entrys from ext and int epg sources :EW
-      if (pEvent && pEvent->TableID() != 0x00)
-         {
-         cEvent *pPreviousEvent = (cEvent *)pSchedule->GetPreviousEvent(pEvent);
-
-         if (pPreviousEvent)
-            {
-            if(Setup.DoubleEpgAction == 0)
-               {
-               pPreviousEvent->SetStartTime(pEvent->StartTime());
-               pPreviousEvent->SetDuration(pEvent->Duration());
-
-               if(Setup.DisableVPS == 0)
-                  {
-                  if(channel)
-                     pPreviousEvent->SetRunningStatus(pEvent->RunningStatus(), channel);
-                  else
-                     pPreviousEvent->SetRunningStatus(pEvent->RunningStatus());
-                  }
-
-               // to use the info of the original epg, update the extern one,
-               // if it has less info
-               char buffer_short_intern[256];
-               char buffer_short_extern[256];
-               int len_short_intern = 0;
-               int len_short_extern = 0;
-
-               if (pEvent->ShortText())
-                  len_short_intern = snprintf (buffer_short_intern, sizeof(buffer_short_intern), "%s", pEvent->ShortText());
-
-               if (pPreviousEvent->ShortText())
-                  len_short_extern = snprintf (buffer_short_extern, sizeof(buffer_short_extern), "%s",pPreviousEvent->ShortText());
-
-               if(len_short_intern > 0)
-                  {
-                  if(len_short_extern < 1)
-                     pPreviousEvent->SetShortText(buffer_short_intern);
-                  else if (len_short_intern > len_short_extern)
-                     pPreviousEvent->SetShortText(buffer_short_intern);
-                  }
-
-               if(pEvent->Description())
-                  {
-                  char buffer_title_intern[4096];
-                  char buffer_title_extern[4096];
-                  int len_title_intern = 0;
-                  int len_title_extern = 0;
-
-                  if (pEvent->Description())
-                     len_title_intern = snprintf (buffer_title_intern, sizeof(buffer_title_intern), "%s", pEvent->Description());
-
-                  if (pPreviousEvent->Description())
-                     len_title_extern = snprintf (buffer_title_extern, sizeof(buffer_title_extern), "%s", pPreviousEvent->Description());
-
-                  if(len_title_intern > 0)
-                     {
-                     if(len_title_extern < 1)
-                        pPreviousEvent->SetDescription(buffer_title_intern);
-                     else if (len_title_intern > len_title_extern)
-                        pPreviousEvent->SetDescription(buffer_title_intern);
-                     }
-                  }
-
-               if(pPreviousEvent->Vps() == 0 && pEvent->Vps() != 0)
-                  pPreviousEvent->SetVps(pEvent->Vps());
-
-               pSchedule->DelEvent(pEvent);
-               pPreviousEvent->FixEpgBugs();
-               }
-            else
-               pSchedule->DelEvent(pPreviousEvent);
-            }
-         }
-#endif /* DDEPGENTRY */
       }
   if (Tid == 0x4E) {
      if (Empty && getSectionNumber() == 0)
