@@ -6,16 +6,12 @@
  *
  * LIRC support added by Carsten Koch <Carsten.Koch@icem.de>  2000-06-16.
  *
- * $Id: lirc.c 2.0 2006/05/28 08:48:13 kls Exp $
+ * $Id: lirc.c 2.1 2011/03/08 15:35:13 kls Exp $
  */
 
 #include "lirc.h"
 #include <netinet/in.h>
 #include <sys/socket.h>
-#ifdef USE_LIRCSETTINGS
-#include "config.h"
-#endif /* LIRCSETTINGS */
-
 
 #define REPEATDELAY 350 // ms
 #define REPEATFREQ 100 // ms
@@ -90,7 +86,8 @@ void cLircRemote::Action(void)
                  }
            }
 
-        if (ready && ret > 21) {
+        if (ready && ret > 0) {
+           buf[ret - 1] = 0;
            int count;
            char KeyName[LIRC_KEY_BUF];
            if (sscanf(buf, "%*x %x %29s", &count, KeyName) != 2) { // '29' in '%29s' is LIRC_KEY_BUF-1!
@@ -98,11 +95,7 @@ void cLircRemote::Action(void)
               continue;
               }
            if (count == 0) {
-#ifdef USE_LIRCSETTINGS
-              if (strcmp(KeyName, LastKeyName) == 0 && FirstTime.Elapsed() < (unsigned int)Setup.LircRepeatDelay)
-#else
               if (strcmp(KeyName, LastKeyName) == 0 && FirstTime.Elapsed() < REPEATDELAY)
-#endif /* LIRCSETTINGS */
                  continue; // skip keys coming in too fast
               if (repeat)
                  Put(LastKeyName, false, true);
@@ -112,34 +105,18 @@ void cLircRemote::Action(void)
               timeout = -1;
               }
            else {
-#ifdef USE_LIRCSETTINGS
-              if (LastTime.Elapsed() < (unsigned int)Setup.LircRepeatFreq)
-#else
               if (LastTime.Elapsed() < REPEATFREQ)
-#endif /* LIRCSETTINGS */
                  continue; // repeat function kicks in after a short delay (after last key instead of first key)
-#ifdef USE_LIRCSETTINGS
-              if (FirstTime.Elapsed() < (unsigned int)Setup.LircRepeatDelay)
-#else
               if (FirstTime.Elapsed() < REPEATDELAY)
-#endif /* LIRCSETTINGS */
                  continue; // skip keys coming in too fast (for count != 0 as well)
               repeat = true;
-#ifdef USE_LIRCSETTINGS
-              timeout = Setup.LircRepeatDelay;
-#else
               timeout = REPEATDELAY;
-#endif /* LIRCSETTINGS */
               }
            LastTime.Set();
            Put(KeyName, repeat);
            }
         else if (repeat) { // the last one was a repeat, so let's generate a release
-#ifdef USE_LIRCSETTINGS
-           if (LastTime.Elapsed() >= (unsigned int)Setup.LircRepeatTimeout) {
-#else
            if (LastTime.Elapsed() >= REPEATTIMEOUT) {
-#endif /* LIRCSETTINGS */
               Put(LastKeyName, false, true);
               repeat = false;
               *LastKeyName = 0;
