@@ -22,11 +22,7 @@ private:
 public:
   cMenuEditItem(const char *Name);
   ~cMenuEditItem();
-#ifdef USE_VALIDINPUT
-  void SetValue(const char *Value, bool HasPre=false, bool HasSucc=false);
-#else
   void SetValue(const char *Value);
-#endif /* VALIDINPUT */
   };
 
 class cMenuEditIntItem : public cMenuEditItem {
@@ -203,9 +199,6 @@ public:
   cMenuSetupPage(void);
   virtual eOSState ProcessKey(eKeys Key);
   void SetPlugin(cPlugin *Plugin);
-#ifdef USE_GRAPHTFT
-  const char* MenuKind() { return "MenuSetupPage"; }
-#endif /* GRAPHTFT */
   };
 
 #endif //__MENUITEMS_H
