@@ -4,17 +4,16 @@
  * See the main source file 'vdr.c' for copyright information and
  * how to reach the author.
  *
- * $Id: recording.c 2.23 2010/03/07 14:06:04 kls Exp $
+ * $Id: recording.c 2.30 2011/04/17 13:53:11 kls Exp $
  */
 
 #include "recording.h"
-#ifdef USE_WAREAGLEICON
-#include "iconpatch.h"
-#endif /* WAREAGLEICON */
 #include <ctype.h>
 #include <dirent.h>
 #include <errno.h>
 #include <fcntl.h>
+#define __STDC_FORMAT_MACROS // Required for format specifiers
+#include <inttypes.h>
 #include <math.h>
 #include <stdio.h>
 #include <string.h>
@@ -60,15 +59,13 @@
 #define DELETEDLIFETIME   300 // seconds after which a deleted recording will be actually removed
 #define DISKCHECKDELTA    100 // seconds between checks for free disk space
 #define REMOVELATENCY      10 // seconds to wait until next check after removing a file
+#define MARKSUPDATEDELTA   10 // seconds between checks for updating editing marks
 
 #define MAX_SUBTITLE_LENGTH  40
 
 #define MAX_LINK_LEVEL  6
 
 bool VfatFileSystem = false;
-#ifdef USE_LIEMIEXT
-bool DirOrderState = false;
-#endif /* LIEMIEXT */
 int InstanceId = 0;
 
 cRecordings DeletedRecordings(true);
@@ -306,9 +303,10 @@ bool cResumeFile::Save(int Index)
 void cResumeFile::Delete(void)
 {
   if (fileName) {
-     if (remove(fileName) < 0 && errno != ENOENT)
+     if (remove(fileName) == 0)
+        Recordings.ResetResume(fileName);
+     else if (errno != ENOENT)
         LOG_ERROR_STR(fileName);
-     Recordings.ResetResume(fileName);
      }
 }
 
@@ -554,13 +552,17 @@ char *ExchangeChars(char *s, bool ToFileSystem)
                      default:
                        if (strchr(InvalidChars, *p) || *p == '.' && (!*(p + 1) || *(p + 1) == FOLDERDELIMCHAR)) { // Windows can't handle '.' at the end of file/directory names
                           int l = p - s;
-                          s = (char *)realloc(s, strlen(s) + 10);
-                          p = s + l;
-                          char buf[4];
-                          sprintf(buf, "#%02X", (unsigned char)*p);
-                          memmove(p + 2, p, strlen(p) + 1);
-                          strncpy(p, buf, 3);
-                          p += 2;
+                          if (char *NewBuffer = (char *)realloc(s, strlen(s) + 10)) {
+                             s = NewBuffer;
+                             p = s + l;
+                             char buf[4];
+                             sprintf(buf, "#%02X", (unsigned char)*p);
+                             memmove(p + 2, p, strlen(p) + 1);
+                             strncpy(p, buf, 3);
+                             p += 2;
+                             }
+                          else
+                             esyslog("ERROR: out of memory");
                           }
                      }
               }
@@ -684,7 +686,7 @@ cRecording::cRecording(const char *FileName)
   const char *p = strrchr(FileName, '/');
 
   name = NULL;
-  info = new cRecordingInfo;
+  info = new cRecordingInfo(fileName);
   if (p) {
      time_t now = time(NULL);
      struct tm tm_r;
@@ -735,9 +737,13 @@ cRecording::cRecording(const char *FileName)
                     if (data[line]) {
                        int len = strlen(s);
                        len += strlen(data[line]) + 1;
-                       data[line] = (char *)realloc(data[line], len + 1);
-                       strcat(data[line], "\n");
-                       strcat(data[line], s);
+                       if (char *NewBuffer = (char *)realloc(data[line], len + 1)) {
+                          data[line] = NewBuffer;
+                          strcat(data[line], "\n");
+                          strcat(data[line], s);
+                          }
+                       else
+                          esyslog("ERROR: out of memory");
                        }
                     else
                        data[line] = strdup(s);
@@ -756,12 +762,16 @@ cRecording::cRecording(const char *FileName)
               // line 1 and line 2 to be the long text:
               int len = strlen(data[1]);
               if (len > 80) {
-                 data[1] = (char *)realloc(data[1], len + 1 + strlen(data[2]) + 1);
-                 strcat(data[1], "\n");
-                 strcat(data[1], data[2]);
-                 free(data[2]);
-                 data[2] = data[1];
-                 data[1] = NULL;
+                 if (char *NewBuffer = (char *)realloc(data[1], len + 1 + strlen(data[2]) + 1)) {
+                    data[1] = NewBuffer;
+                    strcat(data[1], "\n");
+                    strcat(data[1], data[2]);
+                    free(data[2]);
+                    data[2] = data[1];
+                    data[1] = NULL;
+                    }
+                 else
+                    esyslog("ERROR: out of memory");
                  }
               }
            info->SetData(data[0], data[1], data[2]);
@@ -829,10 +839,6 @@ int cRecording::GetResume(void) const
 int cRecording::Compare(const cListObject &ListObject) const
 {
   cRecording *r = (cRecording *)&ListObject;
-#ifdef USE_LIEMIEXT
-  if (DirOrderState)
-     return strcasecmp(FileName(), r->FileName());
-#endif /* LIEMIEXT */
   return strcasecmp(SortName(), r->SortName());
 }
 
@@ -851,17 +857,9 @@ const char *cRecording::FileName(void) const
   return fileName;
 }
 
-#ifdef USE_LIEMIEXT
-const char *cRecording::Title(char Delimiter, bool NewIndicator, int Level, bool Original) const
-#else
 const char *cRecording::Title(char Delimiter, bool NewIndicator, int Level) const
-#endif /* LIEMIEXT */
 {
-#ifdef USE_WAREAGLEICON
-  const char *New = NewIndicator && IsNew() ? Setup.WarEagleIcons ? IsLangUtf8() ? ICON_NEW_UTF8 : ICON_NEW : "*" : " ";
-#else
   char New = NewIndicator && IsNew() ? '*' : ' ';
-#endif /* WAREAGLEICON */
   free(titleBuffer);
   titleBuffer = NULL;
   if (Level < 0 || Level == HierarchyLevels()) {
@@ -872,14 +870,7 @@ const char *cRecording::Title(char Delimiter, bool NewIndicator, int Level) cons
         s++;
      else
         s = name;
-#ifdef USE_LIEMIEXT
-     if (Original) {
-#endif /* LIEMIEXT */
-#ifdef USE_WAREAGLEICON
-     titleBuffer = strdup(cString::sprintf("%02d.%02d.%02d%c%02d:%02d%s%c%s",
-#else
      titleBuffer = strdup(cString::sprintf("%02d.%02d.%02d%c%02d:%02d%c%c%s",
-#endif /* WAREAGLEICON */
                             t->tm_mday,
                             t->tm_mon + 1,
                             t->tm_year % 100,
@@ -889,33 +880,6 @@ const char *cRecording::Title(char Delimiter, bool NewIndicator, int Level) cons
                             New,
                             Delimiter,
                             s));
-#ifdef USE_LIEMIEXT
-        }
-     else {
-        cString RecLength("---");
-        if (Setup.ShowRecLength && FileName()) {
-           int length = cIndexFile::Length(FileName(), IsPesRecording());
-           if (length >= 0)
-              RecLength = cString::sprintf("%d'", length / SecondsToFrames(60, framesPerSecond));
-           }
-        cString RecDate = cString::sprintf("%02d.%02d.%02d", t->tm_mday, t->tm_mon + 1, t->tm_year % 100);
-        cString RecTime = cString::sprintf("%02d:%02d", t->tm_hour, t->tm_min);
-        cString RecDelimiter = cString::sprintf("%c", Delimiter);
-#ifdef USE_WAREAGLEICON
-        titleBuffer = strdup(cString::sprintf("%s%s%s%s%s%s%s%s",
-#else
-        titleBuffer = strdup(cString::sprintf("%s%s%s%c%s%s%s%s",
-#endif /* WAREAGLEICON */
-                               (Setup.ShowRecDate ? *RecDate        : ""),
-                               (Setup.ShowRecDate && Setup.ShowRecTime ? *RecDelimiter : ""),
-                               (Setup.ShowRecTime ? *RecTime        : ""),
-                               New,
-                               (Setup.ShowRecTime || Setup.ShowRecDate ? *RecDelimiter : ""),
-                               (Setup.ShowRecLength ? *RecLength    : ""),
-                               (Setup.ShowRecLength ? *RecDelimiter : ""),
-                               s));
-        }
-#endif /* LIEMIEXT */
      // let's not display a trailing FOLDERDELIMCHAR:
      if (!NewIndicator)
         stripspace(titleBuffer);
@@ -944,17 +908,6 @@ const char *cRecording::Title(char Delimiter, bool NewIndicator, int Level) cons
   return titleBuffer;
 }
 
-#ifdef USE_CUTTIME
-void cRecording::SetStartTime(time_t Start)
-{
-  start=Start;
-  if (fileName) {
-           free(fileName);
-           fileName = NULL;
-           }
-}
-#endif /* CUTTIME */
-
 const char *cRecording::PrefixFileName(char Prefix)
 {
   cString p = PrefixVideoFileName(FileName(), Prefix);
@@ -984,6 +937,14 @@ bool cRecording::IsEdited(void) const
   return *s == '%';
 }
 
+void cRecording::ReadInfo(void)
+{
+  info->Read();
+  priority = info->priority;
+  lifetime = info->lifetime;
+  framesPerSecond = info->framesPerSecond;
+}
+
 bool cRecording::WriteInfo(void)
 {
   cString InfoFileName = cString::sprintf("%s%s", fileName, isPesRecording ? INFOFILESUFFIX ".vdr" : INFOFILESUFFIX);
@@ -1063,45 +1024,6 @@ void cRecording::ResetResume(void) const
   resume = RESUME_NOT_INITIALIZED;
 }
 
-#ifdef USE_LIEMIEXT
-bool cRecording::Rename(const char *newName)
-{
-  bool result = false;
-  struct tm tm_r;
-  struct tm *t = localtime_r(&start, &tm_r);
-  char *localNewName = ExchangeChars(strdup(newName), true);
-  const char *fmt = isPesRecording ? NAMEFORMATPES : NAMEFORMATTS;
-  int ch = isPesRecording ? priority : channel;
-  int ri = isPesRecording ? lifetime : instanceId;
-  char *newFileName = strdup(cString::sprintf(fmt, VideoDirectory, localNewName, t->tm_year + 1900, t->tm_mon + 1, t->tm_mday, t->tm_hour, t->tm_min, ch, ri));
-  free(localNewName);
-  if (strcmp(FileName(), newFileName)) {
-     if (access(newFileName, F_OK) == 0) {
-        isyslog("recording %s already exists", newFileName);
-        }
-     else {
-        isyslog("renaming recording %s to %s", FileName(), newFileName);
-        result = MakeDirs(newFileName, true);
-        if (result)
-           result = RenameVideoFile(FileName(), newFileName);
-        if (result) {
-           free(fileName);
-           fileName = strdup(newFileName);
-           free(name);
-           name = strdup(newName);
-           free(sortBuffer);
-           sortBuffer = NULL;
-           free(titleBuffer);
-           titleBuffer = NULL;
-           }
-        }
-     }
-  free(newFileName);
-  return result;
-}
-
-#endif /* LIEMIEXT */
-
 // --- cRecordings -----------------------------------------------------------
 
 cRecordings Recordings;
@@ -1274,6 +1196,14 @@ void cRecordings::DelByName(const char *FileName)
      }
 }
 
+void cRecordings::UpdateByName(const char *FileName)
+{
+  LOCK_THREAD;
+  cRecording *recording = GetByName(FileName);
+  if (recording)
+     recording->ReadInfo();
+}
+
 int cRecordings::TotalFileSizeMB(void)
 {
   int size = 0;
@@ -1341,12 +1271,40 @@ bool cMark::Save(FILE *f)
 
 bool cMarks::Load(const char *RecordingFileName, double FramesPerSecond, bool IsPesRecording)
 {
-  cMutexLock MutexLock(&MutexMarkFramesPerSecond);
+  fileName = AddDirectory(RecordingFileName, IsPesRecording ? MARKSFILESUFFIX ".vdr" : MARKSFILESUFFIX);
   framesPerSecond = FramesPerSecond;
-  MarkFramesPerSecond = framesPerSecond;
-  if (cConfig<cMark>::Load(AddDirectory(RecordingFileName, IsPesRecording ? MARKSFILESUFFIX ".vdr" : MARKSFILESUFFIX))) {
-     Sort();
-     return true;
+  nextUpdate = 0;
+  lastFileTime = -1; // the first call to Load() must take place!
+  lastChange = 0;
+  return Update();
+}
+
+bool cMarks::Update(void)
+{
+  time_t t = time(NULL);
+  if (t > nextUpdate) {
+     time_t LastModified = LastModifiedTime(fileName);
+     if (LastModified != lastFileTime) // change detected, or first run
+        lastChange = LastModified > 0 ? LastModified : t;
+     int d = t - lastChange;
+     if (d < 60)
+        d = 1; // check frequently if the file has just been modified
+     else if (d < 3600)
+        d = 10; // older files are checked less frequently
+     else
+        d /= 360; // phase out checking for very old files
+     nextUpdate = t + d;
+     if (LastModified != lastFileTime) { // change detected, or first run
+        lastFileTime = LastModified;
+        if (lastFileTime == t)
+           lastFileTime--; // make sure we don't miss updates in the remaining second
+        cMutexLock MutexLock(&MutexMarkFramesPerSecond);
+        MarkFramesPerSecond = framesPerSecond;
+        if (cConfig<cMark>::Load(fileName)) {
+           Sort();
+           return true;
+           }
+        }
      }
   return false;
 }
@@ -1400,74 +1358,14 @@ cMark *cMarks::GetNext(int Position)
   return NULL;
 }
 
-#ifdef USE_JUMPPLAY
-// --- cMarksReload ----------------------------------------------------------
-
-#define MARKS_RELOAD_MS 10000
-
-time_t cMarksReload::lastsavetime = 0;
-
-cMarksReload::cMarksReload(const char *RecordingFileName)
-:recDir(RecordingFileName)
-{
-  struct stat sbuf;
-  cRecording rec(recDir);
-  if (Load(recDir, rec.FramesPerSecond(), rec.IsPesRecording()) &&
-      stat(FileName(), &sbuf) == 0)
-     lastmodtime = sbuf.st_mtime;
-  else
-     lastmodtime = 0;
-  nextreload.Set(MARKS_RELOAD_MS - cTimeMs::Now() % MARKS_RELOAD_MS);
-}
-
-bool cMarksReload::Reload(void)
-{
-  // Check the timestamp of marks.vdr in 10 seconds intervals
-  // Independent but synchronized reloading of marks in two threads
-  if ((Setup.ReloadMarks && nextreload.TimedOut()) ||
-      lastsavetime > lastmodtime) {
-     nextreload.Set(MARKS_RELOAD_MS - cTimeMs::Now() % MARKS_RELOAD_MS);
-     struct stat sbuf;
-     if (stat(FileName(), &sbuf) == 0 && sbuf.st_mtime != lastmodtime) {
-        lastmodtime = sbuf.st_mtime;
-        cRecording rec(recDir);
-        if (Load(recDir, rec.FramesPerSecond(), rec.IsPesRecording()))
-           return true;
-        }
-     }
-  return false;
-}
-
-bool cMarksReload::Save(void)
-{
-  bool ok = cMarks::Save();
-  struct stat sbuf;
-  if (ok && stat(FileName(), &sbuf) == 0)
-     lastsavetime = lastmodtime = sbuf.st_mtime;
-  return ok;
-}
-#endif /* JUMPPLAY */
-
 // --- cRecordingUserCommand -------------------------------------------------
 
 const char *cRecordingUserCommand::command = NULL;
 
-#ifdef USE_DVLRECSCRIPTADDON
-void cRecordingUserCommand::InvokeCommand(const char *State, const char *RecordingFileName, char *chanName)
-#else
 void cRecordingUserCommand::InvokeCommand(const char *State, const char *RecordingFileName)
-#endif /* DVLRECSCRIPTADDON */
 {
   if (command) {
-#ifdef USE_DVLRECSCRIPTADDON
-     cString cmd;
-     if (chanName != NULL)
-        cmd = cString::sprintf("%s %s \"%s\" \"%s\"", command, State, *strescape(RecordingFileName, "\\\"$"), chanName);
-     else
-        cmd = cString::sprintf("%s %s \"%s\"", command, State, *strescape(RecordingFileName, "\\\"$"));
-#else
      cString cmd = cString::sprintf("%s %s \"%s\"", command, State, *strescape(RecordingFileName, "\\\"$"));
-#endif /* DVLRECSCRIPTADDON */
      isyslog("executing '%s'", *cmd);
      SystemExec(cmd);
      }
@@ -1667,7 +1565,7 @@ cIndexFile::cIndexFile(const char *FileName, bool Record, bool IsPesRecording)
               delta = int(buf.st_size % sizeof(tIndexTs));
               if (delta) {
                  delta = sizeof(tIndexTs) - delta;
-                 esyslog("ERROR: invalid file size (%lld) in '%s'", buf.st_size, fileName);
+                 esyslog("ERROR: invalid file size (%"PRId64") in '%s'", buf.st_size, fileName);
                  }
               last = int((buf.st_size + delta) / sizeof(tIndexTs) - 1);
               if (!Record && last >= 0) {
@@ -1766,13 +1664,15 @@ bool cIndexFile::CatchUp(int Index)
                }
             int newLast = int(buf.st_size / sizeof(tIndexTs) - 1);
             if (newLast > last) {
-               if (size <= newLast) {
-                  size *= 2;
-                  if (size <= newLast)
-                     size = newLast + 1;
+               int NewSize = size;
+               if (NewSize <= newLast) {
+                  NewSize *= 2;
+                  if (NewSize <= newLast)
+                     NewSize = newLast + 1;
                   }
-               index = (tIndexTs *)realloc(index, size * sizeof(tIndexTs));
-               if (index) {
+               if (tIndexTs *NewBuffer = (tIndexTs *)realloc(index, NewSize * sizeof(tIndexTs))) {
+                  size = NewSize;
+                  index = NewBuffer;
                   int offset = (last + 1) * sizeof(tIndexTs);
                   int delta = (newLast - last) * sizeof(tIndexTs);
                   if (lseek(f, offset, SEEK_SET) == offset) {
@@ -1791,8 +1691,10 @@ bool cIndexFile::CatchUp(int Index)
                   else
                      LOG_ERROR_STR(fileName);
                   }
-               else
+               else {
                   esyslog("ERROR: can't realloc() index");
+                  break;
+                  }
                }
             }
          else
@@ -1939,18 +1841,6 @@ bool GenerateIndex(const char *FileName)
   return false;
 }
 
-#ifdef USE_LIEMIEXT
-int cIndexFile::Length(const char *FileName, bool IsPesRecording)
-{
-  struct stat buf;
-  cString fullname = cString::sprintf("%s%s", FileName, IsPesRecording ? INDEXFILESUFFIX ".vdr" : INDEXFILESUFFIX);
-  if (FileName && *fullname && access(fullname, R_OK) == 0 && stat(fullname, &buf) == 0)
-     return buf.st_size ? (buf.st_size - 1) / sizeof(tIndexTs) + 1 : 0;
-  return -1;
-}
-
-#endif /* LIEMIEXT */
-
 // --- cFileName -------------------------------------------------------------
 
 #define MAXFILESPERRECORDINGPES 255
@@ -2109,22 +1999,6 @@ cUnbufferedFile *cFileName::SetOffset(int Number, off_t Offset)
   return NULL;
 }
 
-#ifdef USE_HARDLINKCUTTER
-off_t cFileName::MaxFileSize() {
-  const int maxVideoFileSize = isPesRecording ? MAXVIDEOFILESIZEPES : MAXVIDEOFILESIZETS;
-  const int setupMaxVideoFileSize = min(maxVideoFileSize, Setup.MaxVideoFileSize);
-  const int maxFileNumber = isPesRecording ? 255 : 65535;
-
-  const off_t smallFiles = (maxFileNumber * off_t(maxVideoFileSize) - 1024 * Setup.MaxRecordingSize)
-                           / max(maxVideoFileSize - setupMaxVideoFileSize, 1);
-
-  if (fileNumber <= smallFiles)
-     return MEGABYTE(off_t(setupMaxVideoFileSize));
-
-  return MEGABYTE(off_t(maxVideoFileSize));
-}
-#endif /* HARDLINKCUTTER */
-
 cUnbufferedFile *cFileName::NextFile(void)
 {
   return SetOffset(fileNumber + 1);
