@@ -4,7 +4,7 @@
  * See the main source file 'vdr.c' for copyright information and
  * how to reach the author.
  *
- * $Id: recording.h 2.14 2010/03/07 14:06:15 kls Exp $
+ * $Id: recording.h 2.19 2011/04/17 13:18:04 kls Exp $
  */
 
 #ifndef __RECORDING_H
@@ -23,9 +23,6 @@
 #define TIMERMACRO_EPISODE  "EPISODE"
 
 extern bool VfatFileSystem;
-#ifdef USE_LIEMIEXT
-extern bool DirOrderState;
-#endif /* LIEMIEXT */
 extern int InstanceId;
 
 void RemoveDeletedRecordings(void);
@@ -60,6 +57,7 @@ private:
   int lifetime;
   char *fileName;
   cRecordingInfo(const cChannel *Channel = NULL, const cEvent *Event = NULL);
+  bool Read(FILE *f);
   void SetData(const char *Title, const char *ShortText, const char *Description);
   void SetAux(const char *Aux);
 public:
@@ -70,15 +68,11 @@ public:
   const cEvent *GetEvent(void) const { return event; }
   const char *Title(void) const { return event->Title(); }
   const char *ShortText(void) const { return event->ShortText(); }
-#ifdef USE_GRAPHTFT
-  tEventID EventID(void) const { return event->EventID(); }
-#endif /* GRAPHTFT */
   const char *Description(void) const { return event->Description(); }
   const cComponents *Components(void) const { return event->Components(); }
   const char *Aux(void) const { return aux; }
   double FramesPerSecond(void) const { return framesPerSecond; }
   void SetFramesPerSecond(double FramesPerSecond);
-  bool Read(FILE *f);
   bool Write(FILE *f, const char *Prefix = "") const;
   bool Read(void);
   bool Write(void) const;
@@ -114,15 +108,8 @@ public:
   virtual int Compare(const cListObject &ListObject) const;
   const char *Name(void) const { return name; }
   const char *FileName(void) const;
-#ifdef USE_LIEMIEXT
-  const char *Title(char Delimiter = ' ', bool NewIndicator = false, int Level = -1, bool Original = true) const;
-#else
   const char *Title(char Delimiter = ' ', bool NewIndicator = false, int Level = -1) const;
-#endif /* LIEMIEXT */
   const cRecordingInfo *Info(void) const { return info; }
-#ifdef USE_CUTTIME
-  void SetStartTime(time_t Start);
-#endif /* CUTTIME */
   const char *PrefixFileName(char Prefix);
   int HierarchyLevels(void) const;
   void ResetResume(void) const;
@@ -130,6 +117,7 @@ public:
   bool IsNew(void) const { return GetResume() <= 0; }
   bool IsEdited(void) const;
   bool IsPesRecording(void) const { return isPesRecording; }
+  void ReadInfo(void);
   bool WriteInfo(void);
   bool Delete(void);
        // Changes the file name so that it will no longer be visible in the "Recordings" menu
@@ -141,11 +129,6 @@ public:
        // Changes the file name so that it will be visible in the "Recordings" menu again and
        // not processed by cRemoveDeletedRecordingsThread.
        // Returns false in case of error
-#ifdef USE_LIEMIEXT
-  bool Rename(const char *newName);
-       // Changes the file name
-       // Returns false in case of error
-#endif /* LIEMIEXT */
   };
 
 class cRecordings : public cList<cRecording>, public cThread {
@@ -183,6 +166,7 @@ public:
   cRecording *GetByName(const char *FileName);
   void AddByName(const char *FileName, bool TriggerUpdate = true);
   void DelByName(const char *FileName);
+  void UpdateByName(const char *FileName);
   int TotalFileSizeMB(void); ///< Only for deleted recordings!
   };
 
@@ -206,9 +190,14 @@ public:
 
 class cMarks : public cConfig<cMark> {
 private:
+  cString fileName;
   double framesPerSecond;
+  time_t nextUpdate;
+  time_t lastFileTime;
+  time_t lastChange;
 public:
   bool Load(const char *RecordingFileName, double FramesPerSecond = DEFAULTFRAMESPERSECOND, bool IsPesRecording = false);
+  bool Update(void);
   void Sort(void);
   cMark *Add(int Position);
   cMark *Get(int Position);
@@ -216,21 +205,6 @@ public:
   cMark *GetNext(int Position);
   };
 
-#ifdef USE_JUMPPLAY
-class cMarksReload : public cMarks {
-private:
-  cString recDir;
-  cTimeMs nextreload;
-  time_t lastmodtime;
-  static time_t lastsavetime;
-public:
-  cMarksReload(const char *RecordingFileName);
-  bool Reload(void);
-  bool Save(void);
-  };
-
-#endif /* JUMPPLAY */
-
 #define RUC_BEFORERECORDING "before"
 #define RUC_AFTERRECORDING  "after"
 #define RUC_EDITEDRECORDING "edited"
@@ -240,11 +214,7 @@ private:
   static const char *command;
 public:
   static void SetCommand(const char *Command) { command = Command; }
-#ifdef USE_DVLRECSCRIPTADDON
-  static void InvokeCommand(const char *State, const char *RecordingFileName, char *chanName = NULL);
-#else
   static void InvokeCommand(const char *State, const char *RecordingFileName);
-#endif /* DVLRECSCRIPTADDON */
   };
 
 // The maximum size of a single frame (up to HDTV 1920x1080):
@@ -257,23 +227,9 @@ public:
 // before the next independent frame, to have a complete Group Of Pictures):
 #define MAXVIDEOFILESIZETS  1048570 // MB
 #define MAXVIDEOFILESIZEPES    2000 // MB
-#ifdef USE_HARDLINKCUTTER
-#define MINVIDEOFILESIZE          1 // MB
-#else
 #define MINVIDEOFILESIZE        100 // MB
-#endif /* HARDLINKCUTTER */
 #define MAXVIDEOFILESIZEDEFAULT MAXVIDEOFILESIZEPES
 
-#ifdef USE_HARDLINKCUTTER
-#define MINRECORDINGSIZE      25 // GB
-#define MAXRECORDINGSIZE     500 // GB
-#define DEFAULTRECORDINGSIZE 100 // GB
-// Dynamic recording size:
-// Keep recording file size at Setup.MaxVideoFileSize for as long as possible,
-// but switch to MAXVIDEOFILESIZE early enough, so that Setup.MaxRecordingSize
-// will be reached, before recording to file 65535.vdr
-#endif /* HARDLINKCUTTER */
-
 struct tIndexTs;
 class cIndexFileGenerator;
 
@@ -303,10 +259,6 @@ public:
   bool StoreResume(int Index) { return resumeFile.Save(Index); }
   bool IsStillRecording(void);
   void Delete(void);
-#ifdef USE_LIEMIEXT
-  static int Length(const char *FileName, bool IsPesRecording = false);
-       ///< Calculates the recording length without reading the index.
-#endif /* LIEMIEXT */
   };
 
 class cFileName {
@@ -326,10 +278,6 @@ public:
   cUnbufferedFile *Open(void);
   void Close(void);
   cUnbufferedFile *SetOffset(int Number, off_t Offset = 0); // yes, Number is int for easier internal calculating
-#ifdef USE_HARDLINKCUTTER
-  off_t MaxFileSize();
-      // Dynamic file size for this file
-#endif /* HARDLINKCUTTER */
   cUnbufferedFile *NextFile(void);
   };
 
