@@ -4,7 +4,7 @@
  * See the main source file 'vdr.c' for copyright information and
  * how to reach the author.
  *
- * $Id: remux.c 2.47 2010/06/05 13:32:15 kls Exp $
+ * $Id: remux.c 2.53 2011/03/20 10:21:14 kls Exp $
  */
 
 #include "remux.h"
@@ -215,32 +215,6 @@ int cPatPmtGenerator::MakeSubtitlingDescriptor(uchar *Target, const char *Langua
   return i;
 }
 
-#ifdef USE_TTXTSUBS
-int cPatPmtGenerator::MakeTeletextDescriptor(uchar *Target, const tTeletextSubtitlePage *pages, int pageCount)
-{
-  int i = 0, j = 0;
-  Target[i++] = SI::TeletextDescriptorTag;
-  int l = i;
-  Target[i++] = 0x00; // length
-  for (int n = 0; n < pageCount; n++) {
-      const char* Language = pages[n].ttxtLanguage;
-      Target[i++] = *Language++;
-      Target[i++] = *Language++;
-      Target[i++] = *Language++;
-      Target[i++] = (pages[n].ttxtType << 3) + pages[n].ttxtMagazine;
-      Target[i++] = pages[n].ttxtPage;
-      j++;
-      }
-  if (j > 0) {
-     Target[l] = j * 5; // update length
-     IncEsInfoLength(i);
-     return i;
-     }
-  return 0;
-}
-
-#endif /* TTXTSUBS */
-
 int cPatPmtGenerator::MakeLanguageDescriptor(uchar *Target, const char *Language)
 {
   int i = 0;
@@ -251,7 +225,7 @@ int cPatPmtGenerator::MakeLanguageDescriptor(uchar *Target, const char *Language
       Target[i++] = *Language++;
       Target[i++] = *Language++;
       Target[i++] = *Language++;
-      Target[i++] = 0x01;     // audio type
+      Target[i++] = 0x00;     // audio type
       Target[Length] += 0x04; // length
       if (*Language == '+')
          Language++;
@@ -328,9 +302,6 @@ void cPatPmtGenerator::GeneratePmt(const cChannel *Channel)
   if (Channel) {
      int Vpid = Channel->Vpid();
      int Ppid = Channel->Ppid();
-#ifdef USE_TTXTSUBS
-     int Tpid = Channel->Tpid();
-#endif /* TTXTSUBS */
      uchar *p = buf;
      int i = 0;
      p[i++] = 0x02; // table id
@@ -363,12 +334,6 @@ void cPatPmtGenerator::GeneratePmt(const cChannel *Channel)
          i += MakeStream(buf + i, 0x06, Channel->Spid(n));
          i += MakeSubtitlingDescriptor(buf + i, Channel->Slang(n), Channel->SubtitlingType(n), Channel->CompositionPageId(n), Channel->AncillaryPageId(n));
          }
-#ifdef USE_TTXTSUBS
-     if (Tpid) {
-        i += MakeStream(buf + i, 0x06, Tpid);
-        i += MakeTeletextDescriptor(buf + i, Channel->TeletextSubtitlePages(), Channel->TotalTeletextSubtitlePages());
-        }
-#endif /* TTXTSUBS */
 
      int sl = i - SectionLength - 2 + 4; // -2 = SectionLength storage, +4 = length of CRC
      buf[SectionLength] |= (sl >> 8) & 0x0F;
@@ -442,9 +407,6 @@ void cPatPmtParser::Reset(void)
   pmtPid = -1;
   vpid = vtype = 0;
   ppid = 0;
-#ifdef USE_TTXTSUBS
-  tpid = 0;
-#endif /* TTXTSUBS */
 }
 
 void cPatPmtParser::ParsePat(const uchar *Data, int Length)
@@ -530,17 +492,11 @@ void cPatPmtParser::ParsePmt(const uchar *Data, int Length)
      int NumSpids = 0;
      vpid = vtype = 0;
      ppid = 0;
-#ifdef USE_TTXTSUBS
-     tpid = 0;
-#endif /* TTXTSUBS */
      apids[0] = 0;
      dpids[0] = 0;
      spids[0] = 0;
      atypes[0] = 0;
      dtypes[0] = 0;
-#ifdef USE_TTXTSUBS
-     totalTtxtSubtitlePages = 0;
-#endif /* TTXTSUBS */
      SI::PMT::Stream stream;
      for (SI::Loop::Iterator it; Pmt.streamLoop.getNext(stream, it); ) {
          dbgpatpmt("     stream type = %02X, pid = %d", stream.getStreamType(), stream.getPid());
@@ -639,30 +595,6 @@ void cPatPmtParser::ParsePmt(const uchar *Data, int Length)
                                     spids[NumSpids]= 0;
                                     }
                                  break;
-#ifdef USE_TTXTSUBS
-                            case SI::TeletextDescriptorTag: {
-                                 dbgpatpmt(" teletext");
-                                 tpid = stream.getPid();
-                                 SI::TeletextDescriptor *sd = (SI::TeletextDescriptor *)d;
-                                 SI::TeletextDescriptor::Teletext ttxt;
-                                 if (totalTtxtSubtitlePages < MAXTXTPAGES) {
-                                    for (SI::Loop::Iterator it; sd->teletextLoop.getNext(ttxt, it); ) {
-                                        bool isSubtitlePage = (ttxt.getTeletextType() == 0x02) || (ttxt.getTeletextType() == 0x05);
-                                        if (isSubtitlePage && ttxt.languageCode[0]) {
-                                           dbgpatpmt(" '%s:%x.%x'", ttxt.languageCode, ttxt.getTeletextMagazineNumber(), ttxt.getTeletextPageNumber());
-                                           strn0cpy(teletextSubtitlePages[totalTtxtSubtitlePages].ttxtLanguage, I18nNormalizeLanguageCode(ttxt.languageCode), MAXLANGCODE1);
-                                           teletextSubtitlePages[totalTtxtSubtitlePages].ttxtPage = ttxt.getTeletextPageNumber();
-                                           teletextSubtitlePages[totalTtxtSubtitlePages].ttxtMagazine = ttxt.getTeletextMagazineNumber();
-                                           teletextSubtitlePages[totalTtxtSubtitlePages].ttxtType = ttxt.getTeletextType();
-                                           totalTtxtSubtitlePages++;
-                                           if (totalTtxtSubtitlePages >= MAXTXTPAGES)
-                                              break;
-                                           }
-                                        }
-                                    }
-                                 }
-                                 break;
-#endif /* TTXTSUBS */
                             case SI::ISO639LanguageDescriptorTag: {
                                  SI::ISO639LanguageDescriptor *ld = (SI::ISO639LanguageDescriptor *)d;
                                  dbgpatpmt(" '%s'", ld->languageCode);
@@ -734,9 +666,13 @@ void cTsToPes::PutTs(const uchar *Data, int Length)
      return; // skip everything before the first payload start
   Length = TsGetPayload(&Data);
   if (length + Length > size) {
-     size = max(KILOBYTE(2), length + Length);
-     data = (uchar *)realloc(data, size);
-     if (!data) {
+     int NewSize = max(KILOBYTE(2), length + Length);
+     if (uchar *NewData = (uchar *)realloc(data, NewSize)) {
+        data = NewData;
+        size = NewSize;
+        }
+     else {
+        esyslog("ERROR: out of memory");
         Reset();
         return;
         }
@@ -847,8 +783,9 @@ cFrameDetector::cFrameDetector(int Pid, int Type)
   synced = false;
   newFrame = independentFrame = false;
   numPtsValues = 0;
+  numFrames = 0;
   numIFrames = 0;
-  frameDuration = 0;
+  framesPerSecond = 0;
   framesInPayloadUnit = framesPerPayloadUnit = 0;
   payloadUnitOfFrame = 0;
   scanning = false;
@@ -899,8 +836,8 @@ int cFrameDetector::Analyze(const uchar *Data, int Length)
                     return Processed;
                  if (Length < MIN_TS_PACKETS_FOR_FRAME_DETECTOR * TS_SIZE)
                     return Processed; // need more data, in case the frame type is not stored in the first TS packet
-                 if (!frameDuration) {
-                    // frame duration unknown, so collect a sequence of PTS values:
+                 if (framesPerSecond <= 0.0) {
+                    // frame rate unknown, so collect a sequence of PTS values:
                     if (numPtsValues < MaxPtsValues && numIFrames < 2) { // collect a sequence containing at least two I-frames
                        const uchar *Pes = Data + TsPayloadOffset(Data);
                        if (PesHasPts(Pes)) {
@@ -910,6 +847,7 @@ int cFrameDetector::Analyze(const uchar *Data, int Length)
                              dbgframes("#");
                              numPtsValues = 0;
                              numIFrames = 0;
+                             numFrames = 0;
                              }
                           else
                              numPtsValues++;
@@ -925,28 +863,35 @@ int cFrameDetector::Analyze(const uchar *Data, int Length)
                        uint32_t Delta = ptsValues[0];
                        // determine frame info:
                        if (isVideo) {
-                          if (Delta % 3600 == 0)
-                             frameDuration = 3600; // PAL, 25 fps, exact timing
-                          else if (abs(Delta % 3600) == 3599 || abs(Delta % 3600) == 1)
-                             frameDuration = 3600; // PAL, 25 fps, timing with jitter
+                          if (abs(Delta - 3600) <= 1)
+                             framesPerSecond = 25.0;
                           else if (Delta % 3003 == 0)
-                             frameDuration = 3003; // NTSC, 29.97 fps
+                             framesPerSecond = 30.0 / 1.001;
                           else if (abs(Delta - 1800) <= 1) {
-                             frameDuration = 3600; // PAL, 25 fps
-                             framesPerPayloadUnit = -2;
-                             }
-                          else if (Delta == 1501) {
-                             frameDuration = 3003; // NTSC, 29.97 fps
-                             framesPerPayloadUnit = -2;
+                             if (numFrames > 50) {
+                                // this is a "best guess": if there are more than 50 frames between two I-frames, we assume each "frame" actually contains a "field", so two "fields" make one "frame"
+                                framesPerSecond = 25.0;
+                                framesPerPayloadUnit = -2;
+                                }
+                             else
+                                framesPerSecond = 50.0;
                              }
+                          else if (Delta == 1501)
+                             if (numFrames > 50) {
+                                // this is a "best guess": if there are more than 50 frames between two I-frames, we assume each "frame" actually contains a "field", so two "fields" make one "frame"
+                                framesPerSecond = 30.0 / 1.001;
+                                framesPerPayloadUnit = -2;
+                                }
+                             else
+                                framesPerSecond = 60.0 / 1.001;
                           else {
-                             frameDuration = 3600; // unknown, assuming 25 fps
-                             dsyslog("unknown frame duration (%d), assuming 25 fps", Delta);
+                             framesPerSecond = 25.0;
+                             dsyslog("unknown frame delta (%d), assuming 25 fps", Delta);
                              }
                           }
                        else // audio
-                          frameDuration = Delta; // PTS of audio frames is always increasing
-                       dbgframes("\nframe duration = %d  FPS = %5.2f  FPPU = %d\n", frameDuration, 90000.0 / frameDuration, framesPerPayloadUnit);
+                          framesPerSecond = 90000.0 / Delta; // PTS of audio frames is always increasing
+                       dbgframes("\nDelta = %d  FPS = %5.2f  FPPU = %d NF = %d\n", Delta, framesPerSecond, framesPerPayloadUnit, numFrames);
                        }
                     }
                  scanner = EMPTY_SCANNER;
@@ -973,7 +918,6 @@ int cFrameDetector::Analyze(const uchar *Data, int Length)
                                   return Processed; // flush everything before this new frame
                                newFrame = true;
                                independentFrame = ((Data[i + 2] >> 3) & 0x07) == 1; // I-Frame
-                              if (((Data[i + 2] >> 3) & 0x07) == 0) { independentFrame = 1;}
                                if (synced) {
                                   if (framesPerPayloadUnit <= 1)
                                      scanning = false;
@@ -982,6 +926,8 @@ int cFrameDetector::Analyze(const uchar *Data, int Length)
                                   framesInPayloadUnit++;
                                   if (independentFrame)
                                      numIFrames++;
+                                  if (numIFrames == 1)
+                                     numFrames++;
                                   dbgframes("%d ", (Data[i + 2] >> 3) & 0x07);
                                   }
                                if (synced)
@@ -1010,6 +956,8 @@ int cFrameDetector::Analyze(const uchar *Data, int Length)
                                   framesInPayloadUnit++;
                                   if (independentFrame)
                                      numIFrames++;
+                                  if (numIFrames == 1)
+                                     numFrames++;
                                   dbgframes("%02X ", Data[i + 1]);
                                   }
                                if (synced)
@@ -1033,9 +981,9 @@ int cFrameDetector::Analyze(const uchar *Data, int Length)
                                 pid = 0; // let's just ignore any further data
                        }
                      }
-                 if (!synced && frameDuration && independentFrame) {
+                 if (!synced && framesPerSecond > 0.0 && independentFrame) {
                     synced = true;
-                    dbgframes("*");
+                    dbgframes("*\n");
                     Reset();
                     return Processed + TS_SIZE;
                     }
