@@ -4,7 +4,7 @@
  * See the main source file 'vdr.c' for copyright information and
  * how to reach the author.
  *
- * $Id: remux.h 2.26 2010/06/05 13:27:55 kls Exp $
+ * $Id: remux.h 2.28 2011/03/19 16:52:46 kls Exp $
  */
 
 #ifndef __REMUX_H
@@ -171,9 +171,6 @@ protected:
   int MakeStream(uchar *Target, uchar Type, int Pid);
   int MakeAC3Descriptor(uchar *Target, uchar Type);
   int MakeSubtitlingDescriptor(uchar *Target, const char *Language, uchar SubtitlingType, uint16_t CompositionPageId, uint16_t AncillaryPageId);
-#ifdef USE_TTXTSUBS
-  int MakeTeletextDescriptor(uchar *Target, const tTeletextSubtitlePage *pages, int pageCount);
-#endif /* TTXTSUBS */
   int MakeLanguageDescriptor(uchar *Target, const char *Language);
   int MakeCRC(uchar *Target, const uchar *Data, int Length);
   void GeneratePmtPid(const cChannel *Channel);
@@ -219,9 +216,6 @@ private:
   int vpid;
   int ppid;
   int vtype;
-#ifdef USE_TTXTSUBS
-  int tpid;
-#endif /* TTXTSUBS */
   int apids[MAXAPIDS + 1]; // list is zero-terminated
   int atypes[MAXAPIDS + 1]; // list is zero-terminated
   char alangs[MAXAPIDS][MAXLANGCODE2];
@@ -234,10 +228,6 @@ private:
   uint16_t compositionPageIds[MAXSPIDS];
   uint16_t ancillaryPageIds[MAXSPIDS];
   bool updatePrimaryDevice;
-#ifdef USE_TTXTSUBS
-  int totalTtxtSubtitlePages;
-  tTeletextSubtitlePage teletextSubtitlePages[MAXTXTPAGES];
-#endif /* TTXTSUBS */
 protected:
   int SectionLength(const uchar *Data, int Length) { return (Length >= 3) ? ((int(Data[1]) & 0x0F) << 8)| Data[2] : 0; }
 public:
@@ -270,11 +260,6 @@ public:
   int Vtype(void) const { return vtype; }
        ///< Returns the video stream type as defined by the current PMT, or 0 if no video
        ///< stream type has been detected, yet.
-#ifdef USE_TTXTSUBS
-  int Tpid(void) { return tpid; }
-       ///< Returns the teletext pid as defined by the current PMT, or 0 if no teletext
-       ///< pid has been detected, yet.
-#endif /* TTXTSUBS */
   const int *Apids(void) const { return apids; }
   const int *Dpids(void) const { return dpids; }
   const int *Spids(void) const { return spids; }
@@ -289,10 +274,6 @@ public:
   uchar SubtitlingType(int i) const { return (0 <= i && i < MAXSPIDS) ? subtitlingTypes[i] : uchar(0); }
   uint16_t CompositionPageId(int i) const { return (0 <= i && i < MAXSPIDS) ? compositionPageIds[i] : uint16_t(0); }
   uint16_t AncillaryPageId(int i) const { return (0 <= i && i < MAXSPIDS) ? ancillaryPageIds[i] : uint16_t(0); }
-#ifdef USE_TTXTSUBS
-  const tTeletextSubtitlePage *TeletextSubtitlePages() const { return teletextSubtitlePages; }
-  int TotalTeletextSubtitlePages() const { return totalTtxtSubtitlePages; }
-#endif /* TTXTSUBS */
   };
 
 // TS to PES converter:
@@ -364,9 +345,10 @@ private:
   bool independentFrame;
   uint32_t ptsValues[MaxPtsValues]; // 32 bit is enough - we only need the delta
   int numPtsValues;
+  int numFrames;
   int numIFrames;
   bool isVideo;
-  int frameDuration;
+  double framesPerSecond;
   int framesInPayloadUnit;
   int framesPerPayloadUnit; // Some broadcasters send one frame per payload unit (== 1),
                             // some put an entire GOP into one payload unit (> 1), and
@@ -399,7 +381,7 @@ public:
       ///< Returns true if a new frame was detected and this is an independent frame
       ///< (i.e. one that can be displayed by itself, without using data from any
       ///< other frames).
-  double FramesPerSecond(void) { return frameDuration ? 90000.0 / frameDuration : 0; }
+  double FramesPerSecond(void) { return framesPerSecond; }
       ///< Returns the number of frames per second, or 0 if this information is not
       ///< available.
   };
