@@ -4,7 +4,7 @@
  * See the main source file 'vdr.c' for copyright information and
  * how to reach the author.
  *
- * $Id: skinsttng.c 1.28 2008/02/23 10:23:44 kls Exp $
+ * $Id: skinsttng.c 2.7 2011/02/20 13:02:49 kls Exp $
  */
 
 // Star Trek: The Next Generation is a registered trademark of Paramount Pictures
@@ -49,9 +49,12 @@
 #include "symbols/teletext.xpm"
 #include "symbols/volume.xpm"
 
-#define Roundness   10
-#define Gap          5
-#define ScrollWidth  5
+#define Roundness     (Setup.FontOsdSize / 2)
+#define Gap           (Setup.FontOsdSize / 5)
+#define ScrollWidth   (Setup.FontOsdSize / 4)
+#define TextFrame     (Setup.FontOsdSize / 10)
+#define TextSpacing   (Setup.FontOsdSize / 4)
+#define SymbolSpacing (Setup.FontOsdSize / 4)
 
 static cTheme Theme;
 
@@ -161,7 +164,7 @@ cSkinSTTNGDisplayChannel::cSkinSTTNGDisplayChannel(bool WithInfo)
   message = false;
   if (withInfo) {
      x0 = 0;
-     x1 = x0 + font->Width("00:00") + 4;
+     x1 = x0 + font->Width("00:00") + 2 * TextFrame;
      x2 = x1 + Roundness;
      x3 = x2 + Gap;
      x7 = cOsd::OsdWidth();
@@ -179,12 +182,17 @@ cSkinSTTNGDisplayChannel::cSkinSTTNGDisplayChannel(bool WithInfo)
      int yt = (y0 + y1) / 2;
      int yb = (y6 + y7) / 2;
      osd = cOsdProvider::NewOsd(cOsd::OsdLeft(), cOsd::OsdTop() + (Setup.ChannelInfoPos ? 0 : cOsd::OsdHeight() - y7));
-     tArea Areas[] = { { 0, 0, x7 - 1, y7 - 1, 8 } };
-     if (Setup.AntiAlias && osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
+     tArea Areas[] = { { 0, 0, x7 - 1, y7 - 1, 32 } }; // TrueColor
+     if (osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
         osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
      else {
-        tArea Areas[] = { { 0, 0, x7 - 1, y7 - 1, 4 } };
-        osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+        tArea Areas[] = { { 0, 0, x7 - 1, y7 - 1, 8 } }; // 256 colors
+        if (Setup.AntiAlias && osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
+           osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+        else {
+           tArea Areas[] = { { 0, 0, x7 - 1, y7 - 1, 4 } }; // 16 colors
+           osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+           }
         }
      osd->DrawRectangle(x0, y0, x7 - 1, y7 - 1, Theme.Color(clrBackground));
      osd->DrawRectangle(x0, y0, x1 - 1, y1 - 1, clrTransparent);
@@ -217,12 +225,17 @@ cSkinSTTNGDisplayChannel::cSkinSTTNGDisplayChannel(bool WithInfo)
      y0 = 0;
      y1 = lineHeight;
      osd = cOsdProvider::NewOsd(cOsd::OsdLeft(), cOsd::OsdTop() + (Setup.ChannelInfoPos ? 0 : cOsd::OsdHeight() - y1));
-     tArea Areas[] = { { x0, y0, x7 - 1, y1 - 1, 8 } };
-     if (Setup.AntiAlias && osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
+     tArea Areas[] = { { x0, y0, x7 - 1, y1 - 1, 32 } }; // TrueColor
+     if (osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
         osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
      else {
-        tArea Areas[] = { { x0, y0, x7 - 1, y1 - 1, 4 } };
-        osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+        tArea Areas[] = { { x0, y0, x7 - 1, y1 - 1, 8 } }; // 256 colors
+        if (Setup.AntiAlias && osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
+           osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+        else {
+           tArea Areas[] = { { x0, y0, x7 - 1, y1 - 1, 4 } }; // 16 colors
+           osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+           }
         }
      osd->DrawRectangle(x0, y0, x7 - 1, y1 - 1, clrTransparent);
      osd->DrawEllipse  (x0, y0, x1 - 1, y1 - 1, frameColor, 7);
@@ -240,28 +253,27 @@ cSkinSTTNGDisplayChannel::~cSkinSTTNGDisplayChannel()
 void cSkinSTTNGDisplayChannel::SetChannel(const cChannel *Channel, int Number)
 {
   osd->DrawRectangle(x3, y0, x4 - 1, y1 - 1, frameColor);
-  int x = x4 - 5;
+  int x = x4 - SymbolSpacing;
   if (Channel && !Channel->GroupSep()) {
-     int d = 3;
      bool rec = cRecordControls::Active();
-     x -= bmRecording.Width() + d;
+     x -= bmRecording.Width() + SymbolSpacing;
      osd->DrawBitmap(x, y0 + (y1 - y0 - bmRecording.Height()) / 2, bmRecording, Theme.Color(rec ? clrChannelSymbolRecFg : clrChannelSymbolOff), rec ? Theme.Color(clrChannelSymbolRecBg) : frameColor);
-     x -= bmEncrypted.Width() + d;
+     x -= bmEncrypted.Width() + SymbolSpacing;
      osd->DrawBitmap(x, y0 + (y1 - y0 - bmEncrypted.Height()) / 2, bmEncrypted, Theme.Color(Channel->Ca() ? clrChannelSymbolOn : clrChannelSymbolOff), frameColor);
-     x -= bmDolbyDigital.Width() + d;
+     x -= bmDolbyDigital.Width() + SymbolSpacing;
      osd->DrawBitmap(x, y0 + (y1 - y0 - bmDolbyDigital.Height()) / 2, bmDolbyDigital, Theme.Color(Channel->Dpid(0) ? clrChannelSymbolOn : clrChannelSymbolOff), frameColor);
-     x -= bmAudio.Width() + d;
+     x -= bmAudio.Width() + SymbolSpacing;
      osd->DrawBitmap(x, y0 + (y1 - y0 - bmAudio.Height()) / 2, bmAudio, Theme.Color(Channel->Apid(1) ? clrChannelSymbolOn : clrChannelSymbolOff), frameColor);
      if (Channel->Vpid()) {
-        x -= bmTeletext.Width() + d;
+        x -= bmTeletext.Width() + SymbolSpacing;
         osd->DrawBitmap(x, y0 + (y1 - y0 - bmTeletext.Height()) / 2, bmTeletext, Theme.Color(Channel->Tpid() ? clrChannelSymbolOn : clrChannelSymbolOff), frameColor);
         }
      else if (Channel->Apid(0)) {
-        x -= bmRadio.Width() + d;
+        x -= bmRadio.Width() + SymbolSpacing;
         osd->DrawBitmap(x, y0 + (y1 - y0 - bmRadio.Height()) / 2, bmRadio, Theme.Color(clrChannelSymbolOn), frameColor);
         }
      }
-  osd->DrawText(x3 + 2, y0, ChannelString(Channel, Number), Theme.Color(clrChannelName), frameColor, cFont::GetFont(fontOsd), x - x3 - 2);
+  osd->DrawText(x3 + TextFrame, y0, ChannelString(Channel, Number), Theme.Color(clrChannelName), frameColor, cFont::GetFont(fontOsd), x - x3 - TextFrame);
 }
 
 void cSkinSTTNGDisplayChannel::SetEvents(const cEvent *Present, const cEvent *Following)
@@ -276,9 +288,9 @@ void cSkinSTTNGDisplayChannel::SetEvents(const cEvent *Present, const cEvent *Fo
   for (int i = 0; i < 2; i++) {
       const cEvent *e = !i ? Present : Following;
       if (e) {
-         osd->DrawText(x0 + 2, y3 + 2 * i * lineHeight, e->GetTimeString(), Theme.Color(clrChannelEpgTime), frameColor, cFont::GetFont(fontOsd));
-         osd->DrawText(x3 + 2, y3 + 2 * i * lineHeight, e->Title(), Theme.Color(clrChannelEpgTitle), Theme.Color(clrBackground), cFont::GetFont(fontOsd), x4 - x3 - 2);
-         osd->DrawText(x3 + 2, y3 + (2 * i + 1) * lineHeight, e->ShortText(), Theme.Color(clrChannelEpgShortText), Theme.Color(clrBackground), cFont::GetFont(fontSml), x4 - x3 - 2);
+         osd->DrawText(x0 + TextFrame, y3 + 2 * i * lineHeight, e->GetTimeString(), Theme.Color(clrChannelEpgTime), frameColor, cFont::GetFont(fontOsd));
+         osd->DrawText(x3 + TextFrame, y3 + 2 * i * lineHeight, e->Title(), Theme.Color(clrChannelEpgTitle), Theme.Color(clrBackground), cFont::GetFont(fontOsd), x4 - x3 - TextFrame);
+         osd->DrawText(x3 + TextFrame, y3 + (2 * i + 1) * lineHeight, e->ShortText(), Theme.Color(clrChannelEpgShortText), Theme.Color(clrBackground), cFont::GetFont(fontSml), x4 - x3 - TextFrame);
          }
       }
 }
@@ -309,13 +321,13 @@ void cSkinSTTNGDisplayChannel::Flush(void)
         cString date = DayDateTime();
         int w = font->Width(date);
         if (!*lastDate || strcmp(date, lastDate)) {
-           osd->DrawText(x4 - w - 2, y7 - font->Height(), date, Theme.Color(clrChannelDate), frameColor, font, w);
+           osd->DrawText(x4 - w - TextFrame, y7 - font->Height(), date, Theme.Color(clrChannelDate), frameColor, font, w);
            lastDate = date;
            }
         cDevice *Device = cDevice::PrimaryDevice();
         const tTrackId *Track = Device->GetTrack(Device->GetCurrentAudioTrack());
         if (!Track && *lastTrackId.description || Track && strcmp(lastTrackId.description, Track->description)) {
-           osd->DrawText(x3 + 2, y6, Track ? Track->description : "", Theme.Color(clrChannelName), frameColor, font, x4 - x3 - w - 4);
+           osd->DrawText(x3 + TextFrame, y6, Track ? Track->description : "", Theme.Color(clrChannelName), frameColor, font, x4 - x3 - w - 2 * TextFrame);
            strn0cpy(lastTrackId.description, Track ? Track->description : "", sizeof(lastTrackId.description));
            }
         }
@@ -395,21 +407,26 @@ cSkinSTTNGDisplayMenu::cSkinSTTNGDisplayMenu(void)
   int yt = (y0 + y1) / 2;
   int yb = (y6 + y7) / 2;
   osd = cOsdProvider::NewOsd(cOsd::OsdLeft(), cOsd::OsdTop());
-  tArea Areas[] = { { x0, y0, x7 - 1, y7 - 1, 8 } };
-  if (Setup.AntiAlias && osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
+  tArea Areas[] = { { x0, y0, x7 - 1, y7 - 1, 32 } }; // TrueColor
+  if (osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
      osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
   else {
-     tArea Areas[] = { { x0, y0, x7 - 1, y7 - 1, 4 } };
-     if (osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
+     tArea Areas[] = { { x0, y0, x7 - 1, y7 - 1, 8 } }; // 256 colors
+     if (Setup.AntiAlias && osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
         osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
      else {
-        tArea Areas[] = { { x0, y0, x7 - 1, y3 - 1, 2 },
-                          { x0, y3, x3 - 1, y4 - 1, 1 },
-                          { x3, y3, x4 - 1, y4 - 1, 2 },
-                          { x4, y3, x7 - 1, y4 - 1, 2 },
-                          { x0, y4, x7 - 1, y7 - 1, 4 }
-                        };
-        osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+        tArea Areas[] = { { x0, y0, x7 - 1, y7 - 1, 4 } }; // 16 colors
+        if (osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
+           osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+        else {
+           tArea Areas[] = { { x0, y0, x7 - 1, y3 - 1, 2 }, // 2..16 colors
+                             { x0, y3, x3 - 1, y4 - 1, 1 },
+                             { x3, y3, x4 - 1, y4 - 1, 2 },
+                             { x4, y3, x7 - 1, y4 - 1, 2 },
+                             { x0, y4, x7 - 1, y7 - 1, 4 }
+                           };
+           osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+           }
         }
      }
   osd->DrawRectangle(x0, y0, x7 - 1, y7 - 1, Theme.Color(clrBackground));
@@ -493,7 +510,7 @@ void cSkinSTTNGDisplayMenu::SetTitle(const char *Title)
   const cFont *font = cFont::GetFont(fontOsd);
   const char *VDR = " VDR";
   int w = font->Width(VDR);
-  osd->DrawText(x3 + 5, y0, Title, Theme.Color(clrMenuTitle), frameColor, font, x4 - w - x3 - 5);
+  osd->DrawText(x3 + TextSpacing, y0, Title, Theme.Color(clrMenuTitle), frameColor, font, x4 - w - x3 - TextSpacing);
   osd->DrawText(x4 - w, y0, VDR, frameColor, clrBlack, font, w, lineHeight);
 }
 
@@ -501,9 +518,9 @@ void cSkinSTTNGDisplayMenu::SetButtons(const char *Red, const char *Green, const
 {
   cString date = DayDateTime();
   const cFont *font = cFont::GetFont(fontSml);
-  int d = 10;
+  int d = 2 * Gap;
   int d2 = d / 2;
-  int t4 = x4 - font->Width(date) - 2;
+  int t4 = x4 - font->Width(date) - TextFrame;
   int w = t4 - x3;
   int t0 = x3 + d2;
   int t1 = x3 + w / 4;
@@ -558,57 +575,13 @@ void cSkinSTTNGDisplayMenu::SetItem(const char *Text, int Index, bool Current, b
   for (int i = 0; i < MaxTabs; i++) {
       const char *s = GetTabbedText(Text, i);
       if (s) {
-#ifdef USE_LIEMIKUUTIO
-         bool isprogressbar = false;
-         int now = 0, total = 0;
-         // check if progress bar: "[|||||||   ]"
-         if ((strlen(s) > 5 && s[0] == '[' && s[strlen(s) - 1] == ']')) {
-            const char *p = s + 1;
-            // update status
-            isprogressbar = true;
-            for (; *p != ']'; ++p) {
-                // check if progressbar characters
-                if (*p == ' ' || *p == '|') {
-                   // update counters
-                   ++total;
-                   if (*p == '|')
-                      ++now;
-                   }
-                else {
-                   // wrong character detected; not a progressbar
-                   isprogressbar = false;
-                   break;
-                   }
-                }
-            }
-         int xt = x3 + 5 + Tab(i);
-         if (Setup.ShowProgressBar && isprogressbar) {
-            // define x coordinates of progressbar
-            int px0 = xt;
-            int px1 = x3 + (Tab(i + 1)?Tab(i + 1):x4-x3-5) - 1;
-            int px = px0 + max((int)((float) now * (float) (px1 - px0) / (float) total), 1);
-            // define y coordinates of progressbar
-            int py0 = y + 4;
-            int py1 = y + lineHeight - 4;
-            // draw background
-            osd->DrawRectangle(px0, y, (Tab(i + 1)?Tab(i + 1):x4-x3-5) - 1, y + lineHeight - 1, ColorBg);
-            // draw progressbar
-            osd->DrawRectangle(px0,    py0, px,  py1, ColorFg);
-            osd->DrawRectangle(px + 1, py0, px1, py0 + 1, ColorFg);
-            osd->DrawRectangle(px + 1, py1 - 1, px1, py1, ColorFg);
-            osd->DrawRectangle(px1 - 1, py0, px1, py1, ColorFg);
-            }
-         else
-            osd->DrawText(xt, y, s, ColorFg, ColorBg, font, x4 - xt);
-#else
-         int xt = x3 + 5 + Tab(i);
+         int xt = x3 + TextSpacing + Tab(i);
          osd->DrawText(xt, y, s, ColorFg, ColorBg, font, x4 - xt);
-#endif /* LIEMIKUUTIO */
          }
       if (!Tab(i + 1))
          break;
       }
-  SetEditableWidth(x4 - x3 - 5 - Tab(1));
+  SetEditableWidth(x4 - x3 - TextSpacing - Tab(1));
 }
 
 void cSkinSTTNGDisplayMenu::SetScrollbar(int Total, int Offset)
@@ -621,7 +594,7 @@ void cSkinSTTNGDisplayMenu::SetEvent(const cEvent *Event)
   if (!Event)
      return;
   const cFont *font = cFont::GetFont(fontOsd);
-  int xl = x3 + 5;
+  int xl = x3 + TextSpacing;
   int y = y3;
   cTextScroller ts;
   char t[32];
@@ -637,6 +610,15 @@ void cSkinSTTNGDisplayMenu::SetEvent(const cEvent *Event)
      osd->DrawEllipse  (x6, y, x7 - 1, yb - 1, frameColor, 5);
      }
   y += ts.Height();
+  if (Event->ParentalRating()) {
+     cString buffer = cString::sprintf(" %s ", *Event->GetParentalRatingString());
+     const cFont *font = cFont::GetFont(fontSml);
+     int w = font->Width(buffer);
+     osd->DrawText(x4 - w, y, buffer, Theme.Color(clrMenuEventVps), frameColor, font, w);
+     int yb = y + font->Height();
+     osd->DrawRectangle(x5, y, x6 - 1, yb - 1, frameColor);
+     osd->DrawEllipse  (x6, y, x7 - 1, yb - 1, frameColor, 5);
+     }
   y += font->Height();
   ts.Set(osd, xl, y, x4 - xl, y4 - y, Event->Title(), font, Theme.Color(clrMenuEventTitle), Theme.Color(clrBackground));
   y += ts.Height();
@@ -646,21 +628,6 @@ void cSkinSTTNGDisplayMenu::SetEvent(const cEvent *Event)
      y += ts.Height();
      }
   y += font->Height();
-#ifdef USE_PARENTALRATING
-  if (!isempty(Event->GetParentalRatingString())) {
-     const cFont *font = cFont::GetFont(fontSml);
-     ts.Set(osd, xl, y, x4 - xl, y4 - y, Event->GetParentalRatingString(), font, Theme.Color(clrMenuEventShortText), Theme.Color(clrBackground));
-     y += ts.Height();
-     }
-  int i = 0;
-  while (Event->Contents(i++)) {
-        if (!isempty(Event->GetContentsString())) {
-           const cFont *font = cFont::GetFont(fontSml);
-           ts.Set(osd, xl, y, x4 - xl, y4 - y, Event->GetContentsString(), font, Theme.Color(clrMenuEventShortText), Theme.Color(clrBackground));
-           y += ts.Height();
-           }
-        }
-#endif /* PARENTALRATING */
   if (!isempty(Event->Description())) {
      int yt = y;
      int yb = y4 - Roundness;
@@ -679,13 +646,22 @@ void cSkinSTTNGDisplayMenu::SetRecording(const cRecording *Recording)
      return;
   const cRecordingInfo *Info = Recording->Info();
   const cFont *font = cFont::GetFont(fontOsd);
-  int xl = x3 + 5;
+  int xl = x3 + TextSpacing;
   int y = y3;
   cTextScroller ts;
   char t[32];
   snprintf(t, sizeof(t), "%s  %s", *DateString(Recording->start), *TimeString(Recording->start));
   ts.Set(osd, xl, y, x4 - xl, y4 - y, t, font, Theme.Color(clrMenuEventTime), Theme.Color(clrBackground));
   y += ts.Height();
+  if (Info->GetEvent()->ParentalRating()) {
+     cString buffer = cString::sprintf(" %s ", *Info->GetEvent()->GetParentalRatingString());
+     const cFont *font = cFont::GetFont(fontSml);
+     int w = font->Width(buffer);
+     osd->DrawText(x4 - w, y, buffer, Theme.Color(clrMenuEventVps), frameColor, font, w);
+     int yb = y + font->Height();
+     osd->DrawRectangle(x5, y, x6 - 1, yb - 1, frameColor);
+     osd->DrawEllipse  (x6, y, x7 - 1, yb - 1, frameColor, 5);
+     }
   y += font->Height();
   const char *Title = Info->Title();
   if (isempty(Title))
@@ -735,7 +711,7 @@ void cSkinSTTNGDisplayMenu::Flush(void)
      if (!*lastDate || strcmp(date, lastDate)) {
         const cFont *font = cFont::GetFont(fontSml);
         int w = font->Width(date);
-        osd->DrawText(x4 - w - 2, y7 - font->Height(), date, Theme.Color(clrMenuDate), frameColor, font, w);
+        osd->DrawText(x4 - w - TextFrame, y7 - font->Height(), date, Theme.Color(clrMenuDate), frameColor, font, w);
         lastDate = date;
         }
      }
@@ -793,12 +769,17 @@ cSkinSTTNGDisplayReplay::cSkinSTTNGDisplayReplay(bool ModeOnly)
   int yt = (y0 + y1) / 2;
   int yb = (y6 + y7) / 2;
   osd = cOsdProvider::NewOsd(cOsd::OsdLeft(), cOsd::OsdTop() + cOsd::OsdHeight() - y7);
-  tArea Areas[] = { { 0, 0, x7 - 1, y7 - 1, 8 } };
-  if (Setup.AntiAlias && osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
+  tArea Areas[] = { { 0, 0, x7 - 1, y7 - 1, 32 } }; // TrueColor
+  if (osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
      osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
   else {
-     tArea Areas[] = { { 0, 0, x7 - 1, y7 - 1, 4 } };
-     osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+     tArea Areas[] = { { 0, 0, x7 - 1, y7 - 1, 8 } }; // 256 colors
+     if (Setup.AntiAlias && osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
+        osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+     else {
+        tArea Areas[] = { { 0, 0, x7 - 1, y7 - 1, 4 } }; // 16 colors
+        osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+        }
      }
   osd->DrawRectangle(x0, y0, x7 - 1, y7 - 1, ModeOnly ? clrTransparent : Theme.Color(clrBackground));
   if (!ModeOnly) {
@@ -831,7 +812,7 @@ cSkinSTTNGDisplayReplay::~cSkinSTTNGDisplayReplay()
 
 void cSkinSTTNGDisplayReplay::SetTitle(const char *Title)
 {
-  osd->DrawText(x3 + 5, y0, Title, Theme.Color(clrReplayTitle), frameColor, cFont::GetFont(fontSml), x4 - x3 - 5);
+  osd->DrawText(x3 + TextSpacing, y0, Title, Theme.Color(clrReplayTitle), frameColor, cFont::GetFont(fontSml), x4 - x3 - TextSpacing);
 }
 
 static const char *const *ReplaySymbols[2][2][5] = {
@@ -869,7 +850,7 @@ void cSkinSTTNGDisplayReplay::SetTotal(const char *Total)
 {
   const cFont *font = cFont::GetFont(fontSml);
   int w = font->Width(Total);
-  osd->DrawText(x4 - w - 5, y6, Total, Theme.Color(clrReplayTotal), frameColor, font, w);
+  osd->DrawText(x4 - w - TextSpacing, y6, Total, Theme.Color(clrReplayTotal), frameColor, font, w);
 }
 
 void cSkinSTTNGDisplayReplay::SetJump(const char *Jump)
@@ -927,12 +908,17 @@ cSkinSTTNGDisplayVolume::cSkinSTTNGDisplayVolume(void)
   y0 = 0;
   y1 = lineHeight;
   osd = cOsdProvider::NewOsd(cOsd::OsdLeft(), cOsd::OsdTop() + cOsd::OsdHeight() - y1);
-  tArea Areas[] = { { x0, y0, x7 - 1, y1 - 1, 8 } };
-  if (Setup.AntiAlias && osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
+  tArea Areas[] = { { x0, y0, x7 - 1, y1 - 1, 32 } }; // TrueColor
+  if (osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
      osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
   else {
-     tArea Areas[] = { { x0, y0, x7 - 1, y1 - 1, 4 } };
-     osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+     tArea Areas[] = { { x0, y0, x7 - 1, y1 - 1, 8 } }; // 256 colors
+     if (Setup.AntiAlias && osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
+        osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+     else {
+        tArea Areas[] = { { x0, y0, x7 - 1, y1 - 1, 4 } }; // 16 colors
+        osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+        }
      }
   osd->DrawRectangle(x0, y0, x7 - 1, y1 - 1, clrTransparent);
   osd->DrawEllipse  (x0, y0, x1 - 1, y1 - 1, frameColor, 7);
@@ -949,10 +935,10 @@ cSkinSTTNGDisplayVolume::~cSkinSTTNGDisplayVolume()
 
 void cSkinSTTNGDisplayVolume::SetVolume(int Current, int Total, bool Mute)
 {
-  int xl = x3 + 5;
-  int xr = x4 - 5;
-  int yt = y0 + 3;
-  int yb = y1 - 3;
+  int xl = x3 + TextSpacing;
+  int xr = x4 - TextSpacing;
+  int yt = y0 + TextFrame;
+  int yb = y1 - TextFrame;
   if (mute != Mute) {
      osd->DrawRectangle(x3, y0, x4 - 1, y1 - 1, frameColor);
      mute = Mute;
@@ -960,9 +946,9 @@ void cSkinSTTNGDisplayVolume::SetVolume(int Current, int Total, bool Mute)
   cBitmap bm(Mute ? mute_xpm : volume_xpm);
   osd->DrawBitmap(xl, y0 + (y1 - y0 - bm.Height()) / 2, bm, Theme.Color(clrVolumeSymbol), frameColor);
   if (!Mute) {
-     xl += bm.Width() + 5;
+     xl += bm.Width() + TextSpacing;
      int w = (y1 - y0) / 3;
-     int d = 3;
+     int d = TextFrame;
      int n = (xr - xl + d) / (w + d);
      int x = xr - n * (w + d);
      tColor Color = Theme.Color(clrVolumeBarLower);
@@ -1013,7 +999,7 @@ cSkinSTTNGDisplayTracks::cSkinSTTNGDisplayTracks(const char *Title, int NumTrack
   int ItemsWidth = font->Width(Title);
   for (int i = 0; i < NumTracks; i++)
       ItemsWidth = max(ItemsWidth, font->Width(Tracks[i]));
-  ItemsWidth += 10;
+  ItemsWidth += 2 * TextSpacing;
   x0 = 0;
   x1 = lineHeight / 2;
   x3 = (x1 + Roundness + Gap + 7) & ~0x07; // must be multiple of 8
@@ -1042,21 +1028,26 @@ cSkinSTTNGDisplayTracks::cSkinSTTNGDisplayTracks(const char *Title, int NumTrack
   int yt = (y0 + y1) / 2;
   int yb = (y6 + y7) / 2;
   osd = cOsdProvider::NewOsd(cOsd::OsdLeft(), cOsd::OsdTop() + cOsd::OsdHeight() - y7);
-  tArea Areas[] = { { x0, y0, x7 - 1, y7 - 1, 8 } };
-  if (Setup.AntiAlias && osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
+  tArea Areas[] = { { x0, y0, x7 - 1, y7 - 1, 32 } }; // TrueColor
+  if (osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
      osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
   else {
-     tArea Areas[] = { { x0, y0, x7 - 1, y7 - 1, 4 } };
-     if (osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
+     tArea Areas[] = { { x0, y0, x7 - 1, y7 - 1, 8 } }; // 256 colors
+     if (Setup.AntiAlias && osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
         osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
      else {
-        tArea Areas[] = { { x0, y0, x7 - 1, y3 - 1, 2 },
-                          { x0, y3, x3 - 1, y4 - 1, 1 },
-                          { x3, y3, x4 - 1, y4 - 1, 2 },
-                          { x4, y3, x7 - 1, y4 - 1, 2 },
-                          { x0, y4, x7 - 1, y7 - 1, 4 }
-                        };
-        osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+        tArea Areas[] = { { x0, y0, x7 - 1, y7 - 1, 4 } }; // 16 colors
+        if (osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
+           osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+        else {
+           tArea Areas[] = { { x0, y0, x7 - 1, y3 - 1, 2 }, // 2..16 colors
+                             { x0, y3, x3 - 1, y4 - 1, 1 },
+                             { x3, y3, x4 - 1, y4 - 1, 2 },
+                             { x4, y3, x7 - 1, y4 - 1, 2 },
+                             { x0, y4, x7 - 1, y7 - 1, 4 }
+                           };
+           osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+           }
         }
      }
   osd->DrawRectangle(x0, y0, x7 - 1, y7 - 1, Theme.Color(clrBackground));
@@ -1077,7 +1068,7 @@ cSkinSTTNGDisplayTracks::cSkinSTTNGDisplayTracks(const char *Title, int NumTrack
   osd->DrawRectangle(x3, y6, x4 - 1, y7 - 1, frameColor);
   osd->DrawRectangle(x5, y6, x6 - 1, y7 - 1, frameColor);
   osd->DrawEllipse  (x6, y6, x7 - 1, y7 - 1, frameColor, 5);
-  osd->DrawText(x3 + 5, y0, Title, Theme.Color(clrMenuTitle), frameColor, font, x4 - x3 - 5);
+  osd->DrawText(x3 + TextSpacing, y0, Title, Theme.Color(clrMenuTitle), frameColor, font, x4 - x3 - TextSpacing);
   for (int i = 0; i < NumTracks; i++)
       SetItem(Tracks[i], i, false);
 }
@@ -1109,7 +1100,7 @@ void cSkinSTTNGDisplayTracks::SetItem(const char *Text, int Index, bool Current)
         }
      }
   const cFont *font = cFont::GetFont(fontOsd);
-  int xt = x3 + 5;
+  int xt = x3 + TextSpacing;
   osd->DrawText(xt, y, Text, ColorFg, ColorBg, font, x4 - xt);
 }
 
@@ -1127,9 +1118,10 @@ void cSkinSTTNGDisplayTracks::SetAudioChannel(int AudioChannel)
     case 0: bm = &bmAudioStereo; break;
     case 1: bm = &bmAudioLeft;   break;
     case 2: bm = &bmAudioRight;  break;
+    default: ;
     }
   if (bm)
-     osd->DrawBitmap(x3 + 5, y6 + (y7 - y6 - bm->Height()) / 2, *bm, Theme.Color(clrChannelSymbolOn), frameColor);
+     osd->DrawBitmap(x3 + TextSpacing, y6 + (y7 - y6 - bm->Height()) / 2, *bm, Theme.Color(clrChannelSymbolOn), frameColor);
   else
      osd->DrawRectangle(x3, y6, x4 - 1, y7 - 1, frameColor);
 }
@@ -1169,12 +1161,17 @@ cSkinSTTNGDisplayMessage::cSkinSTTNGDisplayMessage(void)
   y0 = 0;
   y1 = lineHeight;
   osd = cOsdProvider::NewOsd(cOsd::OsdLeft(), cOsd::OsdTop() + cOsd::OsdHeight() - y1);
-  tArea Areas[] = { { x0, y0, x7 - 1, y1 - 1, 8 } };
-  if (Setup.AntiAlias && osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
+  tArea Areas[] = { { x0, y0, x7 - 1, y1 - 1, 32 } }; // TrueColor
+  if (osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
      osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
   else {
-     tArea Areas[] = { { x0, y0, x7 - 1, y1 - 1, 2 } };
-     osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+     tArea Areas[] = { { x0, y0, x7 - 1, y1 - 1, 8 } }; // 256 colors
+     if (Setup.AntiAlias && osd->CanHandleAreas(Areas, sizeof(Areas) / sizeof(tArea)) == oeOk)
+        osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+     else {
+        tArea Areas[] = { { x0, y0, x7 - 1, y1 - 1, 2 } }; // 4 colors
+        osd->SetAreas(Areas, sizeof(Areas) / sizeof(tArea));
+        }
      }
   osd->DrawRectangle(x0, y0, x7 - 1, y1 - 1, clrTransparent);
   osd->DrawEllipse  (x0, y0, x1 - 1, y1 - 1, frameColor, 7);
