@@ -4,7 +4,7 @@
  * See the main source file 'vdr.c' for copyright information and
  * how to reach the author.
  *
- * $Id: transfer.h 1.12 2007/01/05 10:45:45 kls Exp $
+ * $Id: transfer.h 2.2 2010/01/29 16:38:09 kls Exp $
  */
 
 #ifndef __TRANSFER_H
@@ -13,32 +13,24 @@
 #include "player.h"
 #include "receiver.h"
 #include "remux.h"
-#include "ringbuffer.h"
-#include "thread.h"
 
-class cTransfer : public cReceiver, public cPlayer, public cThread {
+class cTransfer : public cReceiver, public cPlayer {
 private:
-  cRingBufferLinear *ringBuffer;
-  cRemux *remux;
+  cPatPmtGenerator patPmtGenerator;
 protected:
   virtual void Activate(bool On);
   virtual void Receive(uchar *Data, int Length);
-  virtual void Action(void);
 public:
-  cTransfer(tChannelID ChannelID, int VPid, const int *APids, const int *DPids, const int *SPids);
+  cTransfer(const cChannel *Channel);
   virtual ~cTransfer();
   };
 
 class cTransferControl : public cControl {
-#ifdef USE_LIVEBUFFER
-friend class cLiveBufferControl;
-friend class cLiveBufferManager;
-#endif /* LIVEBUFFER */
 private:
   cTransfer *transfer;
   static cDevice *receiverDevice;
 public:
-  cTransferControl(cDevice *ReceiverDevice, tChannelID ChannelID, int VPid, const int *APids, const int *DPids, const int *SPids);
+  cTransferControl(cDevice *ReceiverDevice, const cChannel *Channel);
   ~cTransferControl();
   virtual void Hide(void) {}
   static cDevice *ReceiverDevice(void) { return receiverDevice; }
