@@ -22,7 +22,7 @@
  *
  * The project's page is at http://www.tvdr.de
  *
- * $Id: vdr.c 2.19 2010/04/05 10:06:16 kls Exp $
+ * $Id: vdr.c 2.20 2010/12/12 13:42:00 kls Exp $
  */
 
 #include <getopt.h>
@@ -587,12 +587,7 @@ int main(int argc, char *argv[])
   RecordingCommands.Load(AddDirectory(ConfigDirectory, "reccmds.conf"));
   SVDRPhosts.Load(AddDirectory(ConfigDirectory, "svdrphosts.conf"), true);
   Keys.Load(AddDirectory(ConfigDirectory, "remote.conf"));
-#ifdef USE_ALTERNATECHANNEL
-  KeyMacros.Load(AddDirectory(ConfigDirectory, "keymacros.conf"), true) &&
-    Channels.LoadAlternativeChannels(AddDirectory(ConfigDirectory, "channel_alternative.conf"));
-#else
   KeyMacros.Load(AddDirectory(ConfigDirectory, "keymacros.conf"), true);
-#endif /* ALTERNATECHANNEL */
   Folders.Load(AddDirectory(ConfigDirectory, "folders.conf"));
 
   if (!*cFont::GetFontFileName(Setup.FontOsd)) {
@@ -924,21 +919,6 @@ int main(int argc, char *argv[])
            Recordings.Update();
            DeletedRecordings.Update();
            }
-#ifdef USE_MCLI
-        cPlugin *mcliPlugin = cPluginManager::GetPlugin("mcli");
-        if (mcliPlugin) {
-           if (!ShutdownHandler.countdown) { // if kPower has been pressed, cMenuShutdown takes precedence over other menus
-              cOsdObject *MyMenu = mcliPlugin->AltMenuAction();
-              if (MyMenu) { // is there any cam-menu waiting?
-                 DELETE_MENU;
-                 if (cControl::Control())
-                    cControl::Control()->Hide();
-                    Menu = MyMenu;
-                    Menu->Show();
-                 }
-              }
-           }
-#endif /* MCLI */
         // CAM control:
         if (!Menu && !cOsd::IsOpen())
            Menu = CamControl();
@@ -949,9 +929,6 @@ int main(int argc, char *argv[])
         cOsdObject *Interact = Menu ? Menu : cControl::Control();
         eKeys key = Interface->GetKey(!Interact || !Interact->NeedsFastResponse());
         if (ISREALKEY(key)) {
-#ifdef USE_PINPLUGIN
-           cStatus::MsgUserAction(key, Interact);
-#endif /* PINPLUGIN */
            EITScanner.Activity();
            // Cancel shutdown countdown:
            if (ShutdownHandler.countdown)
@@ -960,7 +937,7 @@ int main(int argc, char *argv[])
            ShutdownHandler.SetUserInactiveTimeout();
            }
         // Keys that must work independent of any interactive mode:
-        switch (key) {
+        switch (int(key)) {
           // Menu control:
           case kMenu: {
                key = kNone; // nobody else needs to see this key
@@ -1024,16 +1001,10 @@ int main(int argc, char *argv[])
                      cControl::Control()->Hide();
                   cPlugin *plugin = cPluginManager::GetPlugin(PluginName);
                   if (plugin) {
-#ifdef USE_PINPLUGIN
-                  if (!cStatus::MsgPluginProtected(plugin)) {
-#endif /* PINPLUGIN */
                      Menu = plugin->MainMenuAction();
                      if (Menu)
                         Menu->Show();
                      }
-#ifdef USE_PINPLUGIN
-                     }
-#endif /* PINPLUGIN */
                   else
                      esyslog("ERROR: unknown plugin '%s'", PluginName);
                   }
@@ -1214,7 +1185,7 @@ int main(int argc, char *argv[])
               cRemote::PutMacro(key);
               key = kNone;
               }
-           switch (key) {
+           switch (int(key)) {
              // Toggle channels:
              case kChanPrev:
              case k0: {
@@ -1223,26 +1194,13 @@ int main(int argc, char *argv[])
                   Channels.SwitchTo(PreviousChannel[PreviousChannelIndex ^= 1]);
                   break;
                   }
-#ifdef USE_VOLCTRL
-             // Left/Right volume control
-#else
              // Direct Channel Select:
              case k1 ... k9:
              // Left/Right rotates through channel groups:
-#endif /* VOLCTRL */
              case kLeft|k_Repeat:
              case kLeft:
              case kRight|k_Repeat:
              case kRight:
-#ifdef USE_VOLCTRL
-                  if (Setup.LRVolumeControl && Setup.LRChannelGroups < 2) {
-                     cRemote::Put(NORMALKEY(key) == kLeft ? kVolDn : kVolUp, true);
-                     break;
-                     }
-                  // else fall through
-             // Direct Channel Select:
-             case k1 ... k9:
-#endif /* VOLCTRL */
              // Previous/Next rotates through channel groups:
              case kPrev|k_Repeat:
              case kPrev:
@@ -1260,15 +1218,9 @@ int main(int argc, char *argv[])
              // Instant resume of the last viewed recording:
              case kPlay:
                   if (cReplayControl::LastReplayed()) {
-#ifdef USE_PINPLUGIN
-                     if (cStatus::MsgReplayProtected(0, cReplayControl::LastReplayed(), 0, false) == false) {
-#endif /* PINPLUGIN */
                      cControl::Shutdown();
                      cControl::Launch(new cReplayControl);
                      }
-#ifdef USE_PINPLUGIN
-                     }
-#endif /* PINPLUGIN */
                   break;
              default:    break;
              }
